cd "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\JHR_RESUBMISSION\Post_Acceptance\Figures\Fig1_2"


****************************************************************************************************
use G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\working_dataset_learner_20032007_v3.dta , clear 
****************************************************************************************************

set matsize 2000
///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///

* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
tab sample 
/*
   Sample of student classification for |
                            regressions |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
ILR: Enrolled in L2/L3 (or higher) cour |  1,267,599       85.54       85.54
  Never observed in education after KS4 |    141,566        9.55       95.10
 ILR: Max level of education:1 or entry |     67,742        4.57       99.67
ILR: student with unknown level of educ |      4,890        0.33      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,481,797      100.00
*/
keep if sample==1
*(214,198 observations deleted)

* STEP 2: Drop KS4 cohort 2003  -- done already in main do-file 
drop if ks4_acadyr==2003 /*(0 observations deleted)*/

* STEP 3: KEep only those in General FE and Tertiary (drop Sixth Form Students) 
/*
tab derived_inst_type_num
                  derived_inst_type_num |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
      General FE college incl. Tertiary |  1,019,879       80.46       80.46
                     Sixth Form College |    247,720       19.54      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,267,599      100.00

*/
keep if derived_inst_type_num==1
*(247,720 observations deleted)

* STEP 4: Drop those whose main sector based on GLH is in tutorial and enrichment studies or unknown sector 
drop if main_sector_noPLW==99 | main_sector_noPLW==16 | main_sector_noPLW==17 | main_sector_noPLW==100
*(11,619 observations deleted)

* STEP 5: DROP if last year in education is after 2016
drop if last_year_education>=2016
*(21,959 observations deleted)

* STEP 6: DROP those colleges with less than 200 observations
*Institution ID 
gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 200 individuals 
*codebook inst_id if obs<30
*drop if obs<100
*(0 observations deleted)
drop obs

keep if min_acadyear_inst>=2005 & min_acadyear_inst<=2010
* (17,282 observations deleted)


set more off

replace group_HRV_num_w=14 if group_HRV_num_w==99 

tab main_sector, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"
*label var main_sector16 "Unknown"
*label var main_sector17 "Mixed"


* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector==`i'
}

cap drop glh_main_sector_noPWL_n
gen glh_main_sector_noPWL_n=0
forval i=1/15 {
replace glh_main_sector_noPWL_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}

recode jobseek_benefit_2015 (0=1) (1=0)
label var jobseek_benefit_2015 "Did not receive job seeking benefits in 2015"
********************************
*GLOBALS FOR CONTROLS  
********************************




global controls_coh0 " i.ACC_region_clean i.ks4_acadyr i.last_year_education  c.total_years_work total_years_work_sq i.years_since_start_FE"
global controls_coh0_emp " i.ACC_region_clean i.ks4_acadyr i.last_year_education i.years_since_start_FE "

global controls_coh1  "i.mode i.ever_app_aggr"  
global mainsector_coh_old "ib15.main_sector ib15.main_sector#c.total_years_work c.glh_main_sector_n" /*ommitted category: business studies*/


global mainsector_coh "ib15.main_sector_noPLW ib15.main_sector_noPLW#c.total_years_work c.glh_main_sector_noPWL_n" /*ommitted category: business studies*/
global mainsector_coh_bis "ib15.main_sector_noPLW ib15.main_sector_noPLW#c.total_years_work" /*ommitted category: business studies*/

global main_sector_old_bis "ib15.main_sector##c.glh_main_sector_n"
global controls_coh2 "ib0.male ib4.ethnicity ib0.english ib0.non_sen ib0.fsmeligible neigh_pov"
global controls_coh2_red "ib0.male ib4.ethnicity ib0.non_sen"

global controls_coh3 	"sd_ks4_score  i.ks4_OFSTED"  
global controls_coh4 	"ib1.ks3_matlev_v2 ib1.ks3_englev_v2"
global controls_coh5 	"ib0.ks2_englev_v2 ib0.ks2_matlev_v2"

global laggedemployment " ib1.employed_t0_t2"
global laggedbenefits "i.jobseek_benefit_t0_t2"

global college_FE_coh "i.ill_upin" 

global neigh "FEcol_barrier_s_07 FEcol_crime_s_07 FEcol_emp_s_07 FEcol_health_s_07 FEcol_idaci_s_07 FEcol_inc_s_07 ILR_barrier_s_07 ILR_crime_s_07 ILR_emp_s_07 ILR_health_s_07 ILR_inc_s_07 ILR_living_s_07"

global glhtypequal "glh_btec_lev1_n glh_key_funct_lev1_n glh_other_voc_lev1_n glh_nvq_lev1_n glh_btec_lev2_n glh_acad_lev2_n glh_key_funct_lev2_n glh_other_voc_lev2_n glh_nvq_lev2_n glh_btec_lev3_n glh_acad_lev3_n glh_keyskills_lev3_n glh_nvq_lev3_n glh_other_voc_lev3_n glh_voc_lev4_n glh_voc_lev5_n glh_tutorials_gce_gcse_n i.ever_hesa"
global glhawarding "glh_AQA_n glh_CG_n glh_EDEXCEL_n glh_NCFE_n glh_OCR_n"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " total_gl_n_hours_1 total_gl_n_hours_2 total_gl_n_hours_3 total_gl_n_hours_4 total_gl_n_hours_5 total_gl_n_hours_6 total_gl_n_hours_7 total_gl_n_hours_8 total_gl_n_hours_9 total_gl_n_hours_10 total_gl_n_hours_11 total_gl_n_hours_12 total_gl_n_hours_13 total_gl_n_hours_14 total_gl_n_hours_15"
global glhbylevel "total_gl_hours_l1_n total_gl_hours_l2_n total_gl_hours_l3_n total_gl_hours_l4plus_n total_gl_hours_unk_n"
global mainactivity "ib13.group_HRV_num_w " /*excluded category: qualifications below level 2*/

ren years_since_finishFEC_base2017 years_since_finishFEC

gen yr_FEC=0 if years_since_finishFEC>=1 & years_since_finishFEC<=5
replace yr_FEC=1 if years_since_finishFEC>=6 & years_since_finishFEC~=.

gen yr_FEC_m=0 if yr_FEC==0 & male==1
replace yr_FEC_m=1 if yr_FEC==1 & male==1

gen yr_FEC_f=0 if yr_FEC==0 & male==0
replace yr_FEC_f=1 if yr_FEC==1 & male==0

gen ever_hesa_m=0 if ever_hesa==0 & male==1
replace ever_hesa_m=1 if ever_hesa==1 & male==1

gen ever_hesa_f=0 if ever_hesa==0 & male==0
replace ever_hesa_f=1 if ever_hesa==1 & male==0


gen ach_lev3_m=0 if achieved_lev3==0 & male==1
replace ach_lev3_m=1 if achieved_lev3==1 & male==1

gen ach_lev3_f=0 if achieved_lev3==0 & male==0
replace ach_lev3_f=1 if achieved_lev3==1 & male==0

*gen tot_glh_enr=total_gl_hours_l1+total_gl_hours_l2+total_gl_hours_l3+total_gl_hours_l4plus
gen share_glh_ach_m=share_glh_ach if  male==1
gen share_glh_ach_f=share_glh_ach if  male==0

gen tot_glh_ach_m=tot_glh_ach if  male==1
gen tot_glh_ach_f=tot_glh_ach if  male==0

***Age (not banded):
cap drop age_first_fe
gen age_first_fe = (min_acadyear_inst-ks4_acadyr)+15
label var age_first_fe "Age first entered FE college"


*************************************************************************************************************
***REGRESSIONS AND VA ESTIMATES:
*************************************************************************************************************


*forval y=1/1 {

cap drop sample1 
cap drop sample2 
cap drop sample3

gen sample1=(age_first_fe>15 & age_first_fe<21)
gen sample2=(age_first_fe>17 & age_first_fe<21)
gen sample3=(age_first_fe>=17 & age_first_fe<21)

keep if sample1==1
codebook inst_id
*

********************************************************************************************************************************************
*** OUTCOME 1: LOG DAILY EARNINGS IN 2017 
********************************************************************************************************************************************

********************************
*Method 1: RANDOM EFFECTS 
********************************

*** REGRESSIONS 
*****************************************************************************************
*(MALE + FEMALE)
************************************


g female=1-male 

egen id_num=group(id)


**** Collapse ****      
preserve 
foreach var in sd_ks4_score fsmeligible sen achieved_lev3 real_earn_day_adj_2017 real_earn_day_all_2017 ln_adj_real_earn_day_2017 real_earn_adj_2017 ever_hesa tot_glh_ach share_glh_ach employment_2017 {
local lab_`var': variable label `var'
di "`lab_`var''"
}
collapse (mean) sd_ks4_score fsmeligible sen achieved_lev3 real_earn_day_adj_2017 real_earn_day_all_2017 ln_adj_real_earn_day_2017 real_earn_adj_2017 ever_hesa tot_glh_ach share_glh_ach employment_2017 (count) weight=id_num (sum) weight_m=male weight_f=female, by(inst_id)
foreach var in sd_ks4_score fsmeligible sen achieved_lev3 real_earn_day_adj_2017 real_earn_day_all_2017 ln_adj_real_earn_day_2017 real_earn_adj_2017 ever_hesa tot_glh_ach share_glh_ach employment_2017 {
label var `var' "`lab_`var''"
}

gen definition=1
label define definition 1 "by sample and years_since_startFE" 2 "by sample and years_since_startFE and main_sector_noPLW"
label values definition definition
save "data_fig1_2.dta", replace
restore


