****************************************************************************************************
use G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\working_dataset_learner_20032007_v3.dta, clear 
****************************************************************************************************

set matsize 2000
************************************************************
*** PROGRAM SHRINKAGE RANDOM EFFECTS CROSS-SECTION ESTIMATES
************************************************************

///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///

* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
/*tab sample 


   Sample of student classification for |
                            regressions |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
ILR: Enrolled in L2/L3 (or higher) cour |  1,267,599       85.54       85.54
  Never observed in education after KS4 |    141,566        9.55       95.10
 ILR: Max level of education:1 or entry |     67,742        4.57       99.67
ILR: student with unknown level of educ |      4,890        0.33      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,481,797      100.00

*/


keep if sample==1
*codebook id 

* STEP 3: KEep only those in General FE and Tertiary (drop Sixth Form Students) 
/*
. tab derived_inst_type_num

                 derived_inst_type_num |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
      General FE college incl. Tertiary |  1,019,879       80.46       80.46
                     Sixth Form College |    247,720       19.54      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,267,599      100.00


*/
keep if derived_inst_type_num==1
*codebook id 

* STEP 4: Drop those whose main sector based on GLH is in tutorial and enrichment studies or unknown sector 
tab main_sector_noPLW, mi 
drop if main_sector_noPLW==99 | main_sector_noPLW==16 | main_sector_noPLW==17 | main_sector_noPLW==100
*codebook id 


* STEP 5: DROP if last year in education is after 2016
tab last_year_education, mi
drop if last_year_education>=2016
*codebook id 

gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)

su obs, detail
/*
-------------------------------------------------------------
      Percentiles      Smallest
 1%         1042             54
 5%         1874             54
10%         2290             54       Obs             969,019
25%         3075             54       Sum of Wgt.     969,019

50%         4756                      Mean           4821.515
                        Largest       Std. Dev.      2095.517
75%         6272          11204
90%         7463          11204       Variance        4391191
95%         8375          11204       Skewness       .4640876
99%        11204          11204       Kurtosis       2.944786

*/

drop obs


* Step 7: Drop those who started before 2005 and after 2010
keep if min_acadyear_inst>=2005 & min_acadyear_inst<=2010
*codebook id 


set more off

replace group_HRV_num_w=14 if group_HRV_num_w==99 /*some are classified as not observed, replace as unknown*/



*main sector dummies
tab main_sector, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"
*label var main_sector16 "Unknown"
*label var main_sector17 "Mixed"


* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector==`i'
}

cap drop glh_main_sector_noPWL_n
gen glh_main_sector_noPWL_n=0
forval i=1/15 {
replace glh_main_sector_noPWL_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}

recode jobseek_benefit_2015 (0=1) (1=0)
label var jobseek_benefit_2015 "Did not receive job seeking benefits in 2015"
********************************
*GLOBALS FOR CONTROLS  
********************************


global controls_coh0 " i.ACC_region_clean i.ks4_acadyr i.last_year_education   i.years_since_start_FE i.age_first_fe i.mode"
global controls_coh0_emp " i.ACC_region_clean i.ks4_acadyr i.last_year_education i.years_since_start_FE i.age_first_fe i.mode"
global controls_coh0_int " i.ACC_region_clean i.ks4_acadyr i.age_first_fe i.mode" /* to be used with intermediate outcomes */


global controls_coh1  "i.last_year_FEC"  
global mainsector_coh "ib15.main_sector_noPLW " /*ommitted category: business studies*/
global mainsector_int "ib15.main_sector_noPLW " 

global controls_coh2 "ib0.male ib4.ethnicity ib0.english ib0.non_sen neigh_pov"
global controls_coh2_red "ib0.male ib4.ethnicity ib0.non_sen"

global controls_coh3 	"sd_ks4_score  i.ks4_OFSTED"  
global controls_coh4 	"ib1.ks3_matlev_v2 ib1.ks3_englev_v2"
global controls_coh5 	"ib0.ks2_englev_v2 ib0.ks2_matlev_v2"

global laggedemployment " ib1.employed_t0_t2"
global laggedbenefits "i.jobseek_benefit_t0_t2"

global college_FE_coh "i.ill_upin" 

global neigh "FEcol_barrier_s_07 FEcol_crime_s_07 FEcol_emp_s_07 FEcol_health_s_07 FEcol_idaci_s_07 FEcol_inc_s_07 ILR_barrier_s_07 ILR_crime_s_07 ILR_emp_s_07 ILR_health_s_07 ILR_inc_s_07 ILR_living_s_07"
global neigh_alt  "ILR_barrier_s_07 ILR_crime_s_07 ILR_emp_s_07 ILR_health_s_07 ILR_inc_s_07 ILR_living_s_07"

global glhtypequal "glh_btec_lev1_n glh_key_funct_lev1_n glh_other_voc_lev1_n glh_nvq_lev1_n glh_btec_lev2_n glh_acad_lev2_n glh_key_funct_lev2_n glh_other_voc_lev2_n glh_nvq_lev2_n glh_btec_lev3_n glh_acad_lev3_n glh_keyskills_lev3_n glh_nvq_lev3_n glh_other_voc_lev3_n glh_voc_lev4_n glh_voc_lev5_n glh_tutorials_gce_gcse_n i.ever_hesa"
global glhawarding "glh_AQA_n glh_CG_n glh_EDEXCEL_n glh_NCFE_n glh_OCR_n"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " total_gl_n_hours_1 total_gl_n_hours_2 total_gl_n_hours_3 total_gl_n_hours_4 total_gl_n_hours_5 total_gl_n_hours_6 total_gl_n_hours_7 total_gl_n_hours_8 total_gl_n_hours_9 total_gl_n_hours_10 total_gl_n_hours_11 total_gl_n_hours_12 total_gl_n_hours_13 total_gl_n_hours_14 total_gl_n_hours_15"
global glhbylevel "total_gl_hours_l1_n total_gl_hours_l2_n total_gl_hours_l3_n total_gl_hours_l4plus_n total_gl_hours_unk_n"
global mainactivity "ib13.group_HRV_num_w " /*excluded category: qualifications below level 2*/



ren years_since_finishFEC_base2017 years_since_finishFEC

gen yr_FEC=0 if years_since_finishFEC>=1 & years_since_finishFEC<=5
replace yr_FEC=1 if years_since_finishFEC>=6 & years_since_finishFEC~=.

gen yr_FEC_m=0 if yr_FEC==0 & male==1
replace yr_FEC_m=1 if yr_FEC==1 & male==1

gen yr_FEC_f=0 if yr_FEC==0 & male==0
replace yr_FEC_f=1 if yr_FEC==1 & male==0

gen ever_hesa_m=0 if ever_hesa==0 & male==1
replace ever_hesa_m=1 if ever_hesa==1 & male==1

gen ever_hesa_f=0 if ever_hesa==0 & male==0
replace ever_hesa_f=1 if ever_hesa==1 & male==0


gen ach_lev3_m=0 if achieved_lev3==0 & male==1
replace ach_lev3_m=1 if achieved_lev3==1 & male==1

gen ach_lev3_f=0 if achieved_lev3==0 & male==0
replace ach_lev3_f=1 if achieved_lev3==1 & male==0

*gen tot_glh_enr=total_gl_hours_l1+total_gl_hours_l2+total_gl_hours_l3+total_gl_hours_l4plus
gen share_glh_ach_m=share_glh_ach if  male==1
gen share_glh_ach_f=share_glh_ach if  male==0

gen tot_glh_ach_m=tot_glh_ach if  male==1
gen tot_glh_ach_f=tot_glh_ach if  male==0

***Age (not banded):
cap drop age_first_fe
gen age_first_fe = (min_acadyear_inst-ks4_acadyr)+15
label var age_first_fe "Age first entered FE college"


*************************************************************************************************************
***REGRESSIONS AND VA ESTIMATES:
*************************************************************************************************************


*forval y=1/1 {

cap drop sample1 
cap drop sample2 
cap drop sample3

gen sample1=(age_first_fe>=16 & age_first_fe<21)
gen sample2=(age_first_fe>17 & age_first_fe<21)
gen sample3=(age_first_fe>=17 & age_first_fe<21)

*keep if sample`y'==1
keep if sample2==1


 
***********************************************************************************************************************************************************************
***********************************************************************************************************************************************************************
***********************************************************************************************************************************************************************
***********************************************************************************************************************************************************************


********************************
*Method 1: RANDOM EFFECTS 
********************************

********************************************************************************************************************************************
*** OUTCOME 1: LOG DAILY EARNINGS IN 2017 
********************************************************************************************************************************************
preserve 
reg ln_adj_real_earn_day_2017 c.real_earn_adj_t0_t2##i.real_earn_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)

keep if sample_coh==1 
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

count
**** Collapse ****      
keep sd_ks4_score fsmeligible inst_id
foreach var in sd_ks4_score fsmeligible  {
local lab_`var': variable label `var'
di "`lab_`var''"
}
collapse (mean) sd_ks4_score fsmeligible (count) weight=fsmeligible, by(inst_id)
foreach var in sd_ks4_score fsmeligible  {
label var `var' "`lab_`var''"
}

g fsm=round(fsmeligible*100)
label var fsm "FSM eligible in KS4 year (%)"


*Merging in VA data 
merge 1:1 inst_id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec9\2_Young_CrossSection_Spec9_all.dta"
drop _m 

*best is last: 
egen ln_wage_ycs_spec9_rk=rank(adj_va_ln_wage_ycs_spec9), unique
egen n_ln_wage_ycs_spec9_rk=count(adj_va_ln_wage_ycs_spec9) if adj_va_ln_wage_ycs_spec9!=.
gen  ln_wage_ycs_spec9_pcrank =(ln_wage_ycs_spec9_rk-1)/(n_ln_wage_ycs_spec9_rk-1)*100 if adj_va_ln_wage_ycs_spec9!=.

***SCATTER: 
foreach var in fsm  {
local laby: variable label `var'
pwcorr `var' ln_wage_ycs_spec9_pcrank  [aweight=weight], sig
local corr: di %8.3g r(rho)
matrix sign=r(sig)
local sign_c: di %8.3g sign[1,2]
twoway ( scatter `var' ln_wage_ycs_spec9_pcrank [aweight=weight], msize(tiny) xlabel(0(20)100, nogrid angle(horizontal)) ) (lfit `var' ln_wage_ycs_spec9_pcrank [aweight=weight], color(emerald) msize(tiny)  ), ytitle(`laby') xtitle("VA Percentile Rank") legend(off) note({&rho}=`corr' (`sign_c')) scheme(s1mono)
graph export "fig_6a", as(pdf) replace
}


restore




************************************************************************************************************************
*LOG ANNUAL EARNINGS
*****************************************************************************************
*(MALE + FEMALE)
************************************
preserve
reg ln_real_earn_adj_2017 c.real_earn_adj_t0_t2##i.real_earn_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh
cap drop sample_coh 
gen sample_coh=(e(sample)==1)

keep if sample_coh==1 
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

count
**** Collapse ****      
keep sd_ks4_score fsmeligible inst_id
foreach var in sd_ks4_score fsmeligible  {
local lab_`var': variable label `var'
di "`lab_`var''"
}
collapse (mean) sd_ks4_score fsmeligible (count) weight=fsmeligible, by(inst_id)
foreach var in sd_ks4_score fsmeligible  {
label var `var' "`lab_`var''"
}

g fsm=round(fsmeligible*100)
label var fsm "FSM eligible in KS4 year (%)"


*Merging in VA data 
merge 1:1 inst_id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec9\2_Young_CrossSection_Spec9_all.dta"
drop _m 


*adj_va_ln_an_earn_ycs_spec9

egen ln_an_earn_ycs_spec9_rk=rank(adj_va_ln_an_earn_ycs_spec9), unique
egen n_ln_an_earn_ycs_spec9_rk=count(adj_va_ln_wage_ycs_spec9) if adj_va_ln_an_earn_ycs_spec9!=.
gen  ln_an_earn_ycs_spec9_pcrank =(ln_an_earn_ycs_spec9_rk-1)/(n_ln_an_earn_ycs_spec9_rk-1)*100 if adj_va_ln_an_earn_ycs_spec9!=.


***SCATTER: 
foreach var in fsm  {
local laby: variable label `var'
pwcorr `var' ln_an_earn_ycs_spec9_pcrank  [aweight=weight], sig
local corr: di %8.3g r(rho)
matrix sign=r(sig)
local sign_c: di %8.3g sign[1,2]
twoway ( scatter `var' ln_an_earn_ycs_spec9_pcrank [aweight=weight], msize(tiny) xlabel(0(20)100, nogrid angle(horizontal)) ) (lfit `var' ln_an_earn_ycs_spec9_pcrank [aweight=weight], color(emerald) msize(tiny)  ), ytitle(`laby') xtitle("VA Percentile Rank") legend(off) note({&rho}=`corr' (`sign_c')) scheme(s1mono)

graph export "fig_6d.pdf", as(pdf) replace

}


restore


******************************************************************************************	
***Regression in LEVELS (no log) but ALL SAMPLE INCLUDING THOSE WITH EARNINGS EQUAL 0
**********************************************************************************************
*Male+Female
*******************************************************************************************
preserve
reg real_earn_day_all_2017 c.real_earn_day_all_t0_t2##i.real_earn_day_all_t0_t2_meas   $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)

keep if sample_coh==1 
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

count
**** Collapse ****      
keep sd_ks4_score fsmeligible inst_id
foreach var in sd_ks4_score fsmeligible  {
local lab_`var': variable label `var'
di "`lab_`var''"
}
collapse (mean) sd_ks4_score fsmeligible (count) weight=fsmeligible, by(inst_id)
foreach var in sd_ks4_score fsmeligible  {
label var `var' "`lab_`var''"
}

g fsm=round(fsmeligible*100)
label var fsm "FSM eligible in KS4 year (%)"


*Merging in VA data 
merge 1:1 inst_id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec9\2_Young_CrossSection_Spec9_all.dta"
drop _m 


*best is last: 
egen  wage_all_ycs_spec9_rk=rank(adj_va_wage_all_ycs_spec9), unique
egen n_wage_all_ycs_spec9_rk=count(adj_va_wage_all_ycs_spec9) if adj_va_wage_all_ycs_spec9!=.
gen  wage_all_ycs_spec9_pcrank =(wage_all_ycs_spec9_rk-1)/(n_wage_all_ycs_spec9_rk-1)*100 if adj_va_wage_all_ycs_spec9!=.


***SCATTER: 
foreach var in fsm  {
local laby: variable label `var'
pwcorr `var' wage_all_ycs_spec9_pcrank  [aweight=weight], sig
local corr: di %8.3g r(rho)
matrix sign=r(sig)
local sign_c: di %8.3g sign[1,2]
twoway ( scatter `var' wage_all_ycs_spec9_pcrank [aweight=weight], msize(tiny) xlabel(0(20)100, nogrid angle(horizontal)) ) (lfit `var' wage_all_ycs_spec9_pcrank [aweight=weight], color(emerald) msize(tiny)), ytitle(`laby') xtitle("VA Percentile Rank")  legend(off) note({&rho}=`corr' (`sign_c')) scheme(s1mono)
graph export "fig_6c.pdf", as(pdf) replace

}


restore



********************************************************************************************************************************************
*** OUTCOME 2: EMPLOYED MORE THAN 90 DAYS IN 2017 
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************
*5)  FULL CONTROLS
preserve
reg employment_2017    $controls_coh0_emp $mainsector_coh $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)

keep if sample_coh==1 
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

count

**** Collapse ****      
keep sd_ks4_score fsmeligible inst_id
foreach var in sd_ks4_score fsmeligible  {
local lab_`var': variable label `var'
di "`lab_`var''"
}
collapse (mean) sd_ks4_score fsmeligible (count) weight=fsmeligible, by(inst_id)
foreach var in sd_ks4_score fsmeligible  {
label var `var' "`lab_`var''"
}

g fsm=round(fsmeligible*100)
label var fsm "FSM eligible in KS4 year (%)"


*Merging in VA data 
merge 1:1 inst_id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec9\2_Young_CrossSection_Spec9_all.dta"
drop _m 


*best is last: 
egen  va_emp_ycs_spec9_rk=rank(adj_va_emp_ycs_spec9), unique
egen n_va_emp_ycs_spec9_rk=count(adj_va_emp_ycs_spec9) if adj_va_emp_ycs_spec9!=.
gen  va_emp_ycs_spec9_pcrank =(va_emp_ycs_spec9_rk-1)/(n_va_emp_ycs_spec9_rk-1)*100 if adj_va_emp_ycs_spec9!=.



***SCATTER: 
foreach var in fsm  {
local laby: variable label `var'
pwcorr `var' va_emp_ycs_spec9_pcrank  [aweight=weight], sig
local corr: di %8.3g r(rho)
matrix sign=r(sig)
local sign_c: di %8.3g sign[1,2]
twoway ( scatter `var' va_emp_ycs_spec9_pcrank [aweight=weight], msize(tiny) xlabel(0(20)100, nogrid angle(horizontal)) ) (lfit `var' va_emp_ycs_spec9_pcrank [aweight=weight], color(emerald) msize(tiny)  ), ytitle(`laby') xtitle("VA Percentile Rank" )  legend(off) note({&rho}=`corr' (`sign_c')) scheme(s1mono)
graph export "fig_6b.pdf", as(pdf) replace
}


restore


