cd "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\JHR_RESUBMISSION\Post_Acceptance\Figures\Fig7"


clear all
clear matrix
cap log close
set more off

use returns_young_males.dta, clear

gen sex = "male"
gen age = "young"

append using returns_young_females

replace sex = "female" if sex == ""
replace age = "young" if age == ""

append using returns_adult_males

replace sex = "male" if sex == ""
replace age = "adult" if age == ""

append using returns_adult_females

replace sex = "female" if sex == ""
replace age = "adult" if age == ""

* Cleaning 
replace var1 = strtrim(var1)
drop if var1 == "Observations"
drop var2-var4
gen order = _n 
replace order = order - 1 if var1 == ""
gen se5 = return[_n+1] if var1 != ""
gen se1 = var5[_n+1] if var1 != ""
drop if var1 == ""
drop order

foreach var in se5 se1 {
	replace `var' = subinstr(`var', " ", "", .)
	replace `var' = substr(`var', 8, 6)
	replace `var' = subinstr(`var', "{", "0", .)
	destring `var', replace
}

replace var7 = subinstr(var7, " ", "", .)
gen enrol = substr(var7, 1, 4)
replace enrol = subinstr(enrol, "\", "", .)
destring enrol, replace
drop var7

replace return = subinstr(return, "*", "", .)
replace return = strtrim(return)
destring return, replace
ren return return5

replace var5 = subinstr(var5, "*", "", .)
replace var5 = strtrim(var5)
destring var5, replace
ren var5 return1 

gsort sex age -enrol
bys sex age: gen order = _n
keep if enrol >= 5

* Reshape 
preserve
	drop return1 se1
	ren return5 return
	ren se5 se
	gen cat = 5
	tempfile cat5
	save `cat5', replace
restore

drop *5
ren return1 return
ren se1 se

append using `cat5'
replace cat = 1 if cat == .
label define cat 1 "1 year" 5 "5 years"
label values cat cat

* CI
gen xu = return + 1.96*se
gen xl = return - 1.96*se


*** FEMALES ***

preserve
	keep if sex == "female" & age == "young"
	drop order
	sort age return

	foreach var in return se xu xl {
		replace `var' = `var'*100
	}
	
	sort enrol var1 cat 
	
	gen order = 1 if _n == 1
	replace order = 2 if _n == 2
	
	replace order = 4 if _n == 3
	replace order = 5 if _n == 4
	
	replace order = 7 if _n == 5
	replace order = 8 if _n == 6
	
	replace order = 10 if _n == 7
	replace order = 11 if _n == 8
	
	replace order = 13 if _n == 9
	replace order = 14 if _n == 10
	
	replace order = 16 if _n == 11
	replace order = 17 if _n == 12
	
	bys var1: egen mean = mean(order) // for bars
	
	sort order
	
	mylabels 0(5)20, suffix("%") local(ylab)
	mylabels 0(5)25, suffix("%") local(ylab2)
	
	#d;
	twoway scatter return order if cat == 1, msymbol(Dh) yaxis(1) mcolor(black) ||
		   scatter return order if cat == 5, msymbol(Th) yaxis(1) mcolor(black) ||
		   rcap xu xl order if age == "young", yaxis(1) color(gs9) lcolor(gs9) ||
		   rcap xu xl order if age == "adult", yaxis(1) color(gs4) || // "phantom" category for making legend work
		   bar enrol mean if inlist(order, 1, 4, 7, 10, 13, 16), yaxis(2) color(black%10)
		   xlabel(1.5 "Leisure & Tourism" 
				  4.5 "Prep for Life & Work" 
				  7.5 "Arts & Media"
				  10.5 "Business Admin & Law"
				  13.5 "Retail"
				  16.5 "Health & Pub Services",
				  angle(45) labsize(small))
				  xtitle("")
				  ytitle("Return")
				  ytitle("Share of students", axis(2))
				  ylabel(`ylab', axis(1))
				  ylabel(`ylab2', axis(2))
				  title("Young", color(black))
          graphregion(fcolor(white) color(white) lcolor(white))
		  legend(order(1 "After 1 year" 2 "After 5 years" 5 "Students enrolled") rows(1) size(small) region(color(white)));
	#d cr
	graph save young, replace
restore


preserve
	keep if sex == "female" & age == "adult"
	drop order
	sort age return

	foreach var in return se xu xl {
		replace `var' = `var'*100
	}
	
	sort enrol var1 cat 
	
	gen order = 1 if _n == 1
	replace order = 2 if _n == 2
	
	replace order = 4 if _n == 3
	replace order = 5 if _n == 4
	
	replace order = 7 if _n == 5
	replace order = 8 if _n == 6
	
	replace order = 10 if _n == 7
	replace order = 11 if _n == 8
	
	replace order = 13 if _n == 9
	replace order = 14 if _n == 10
	
	replace order = 16 if _n == 11
	replace order = 17 if _n == 12
	
	bys var1: egen mean = mean(order) // for bars
	
	sort order
	
	mylabels -4(2)4, suffix("%") local(ylab)
	mylabels 0(5)30, suffix("%") local(ylab2)
	
	#d;
	twoway scatter return order if cat == 1, msymbol(Dh) yaxis(1) mcolor(black) ||
		   scatter return order if cat == 5, msymbol(Th) yaxis(1) mcolor(black) ||
		   rcap xu xl order if age == "young", yaxis(1) color(gs9) lcolor(gs9) ||
		   rcap xu xl order if age == "adult", yaxis(1) color(gs4) || // "phantom" category for making legend work
		   bar enrol mean if inlist(order, 1, 4, 7, 10, 13, 16), yaxis(2) color(black%10)
		   xlabel(1.5 "Prep for Life & Work" 
				  4.5 "ICT"  
				  7.5 "Retail"
				  10.5 "Education & Training"
				  13.5 "Business Admin & Law"
				  16.5 "Health & Pub Services",
				  angle(45) labsize(small))
				  xtitle("")
				  ytitle("Return")
				  ytitle("Share of students", axis(2))
				  ylabel(`ylab', axis(1))
				  ylabel(`ylab2', axis(2))
				   title("Adults", color(black))
          graphregion(fcolor(white) color(white) lcolor(white))
		  legend(order(1 "After 1 year" 2 "After 5 years" 5 "Students enrolled") rows(1) size(small) region(color(white)));
	#d cr
	graph save adult, replace
restore


grc1leg2 young.gph adult.gph,/* xcommon ycommon*/ graphregion(color(white))
cap erase young.gph 
cap erase adult.gph

graph export "female_returns_VA_v3.pdf", replace 


*** MALES ***

preserve
	keep if sex == "male" & age == "young"
	drop order
	sort age return

	foreach var in return se xu xl {
		replace `var' = `var'*100
	}
	
	sort enrol var1 cat 
	
	gen order = 1 if _n == 1
	replace order = 2 if _n == 2
	
	replace order = 4 if _n == 3
	replace order = 5 if _n == 4
	
	replace order = 7 if _n == 5
	replace order = 8 if _n == 6
	
	replace order = 10 if _n == 7
	replace order = 11 if _n == 8
	
	replace order = 13 if _n == 9
	replace order = 14 if _n == 10
	
	replace order = 16 if _n == 11
	replace order = 17 if _n == 12
	
	replace order = 19 if _n == 13
	replace order = 20 if _n == 14
	
	replace order = 22 if _n == 15
	replace order = 23 if _n == 16
	
	bys var1: egen mean = mean(order) // for bars
	
	sort order
	
	mylabels -5(5)10, suffix("%") local(ylab)
	mylabels 0(5)20, suffix("%") local(ylab2)
	
	#d;
	twoway scatter return order if cat == 1, msymbol(Dh) yaxis(1) mcolor(black) ||
		   scatter return order if cat == 5, msymbol(Th) yaxis(1) mcolor(black) ||
		   rcap xu xl order if age == "young", yaxis(1) color(gs9) lcolor(gs9) ||
		   rcap xu xl order if age == "adult", yaxis(1) color(gs4) || // "phantom" category for making legend work
		   bar enrol mean if inlist(order, 1, 4, 7, 10, 13, 16, 19, 22), yaxis(2) color(black%10)
		   xlabel(1.5 "ICT"
				  4.5 "Business Admin & Law"
				  7.5 "Health & Pub Services"
				  10.5 "Leisure & Tourism"  
				  13.5 "Prep for Life & Work"
				  16.5 "Arts & Media"
				  19.5 "Construction"
				  22.5 "Engineering & Manuf.",
				  angle(45) labsize(small))
				  xtitle("")
				  ytitle("Return")
				  ytitle("Share of students", axis(2))
				  ylabel(`ylab', axis(1))
				  ylabel(`ylab2', axis(2))
				  title("Young", color(black))
          graphregion(fcolor(white) color(white) lcolor(white))
		  legend(order(1 "After 1 year" 2 "After 5 years" 5 "Students enrolled") rows(1) size(small) region(color(white)));
	#d cr
	graph save young, replace
restore


preserve
	keep if sex == "male" & age == "adult"
	drop order
	sort age return

	foreach var in return se xu xl {
		replace `var' = `var'*100
	}
	
	sort enrol var1 cat 
	
	gen order = 1 if _n == 1
	replace order = 2 if _n == 2
	
	replace order = 4 if _n == 3
	replace order = 5 if _n == 4
	
	replace order = 7 if _n == 5
	replace order = 8 if _n == 6
	
	replace order = 10 if _n == 7
	replace order = 11 if _n == 8
	
	replace order = 13 if _n == 9
	replace order = 14 if _n == 10
	
	replace order = 16 if _n == 11
	replace order = 17 if _n == 12
	
	replace order = 19 if _n == 13
	replace order = 20 if _n == 14
	
	bys var1: egen mean = mean(order) // for bars
	
	sort order
	
	mylabels -2(2)4, suffix("%") local(ylab)
	mylabels 0(5)20, suffix("%") local(ylab2)
	
	#d;
	twoway scatter return order if cat == 1, msymbol(Dh) yaxis(1) mcolor(black) ||
		   scatter return order if cat == 5, msymbol(Th) yaxis(1) mcolor(black) ||
		   rcap xu xl order if age == "young", yaxis(1) color(gs9) lcolor(gs9) ||
		   rcap xu xl order if age == "adult", yaxis(1) color(gs4) || // "phantom" category for making legend work
		   bar enrol mean if inlist(order, 1, 4, 7, 10, 13, 16, 19), yaxis(2) color(black%10)
		   xlabel(1.5 "Education & Training"
		          4.5 "Retail"
				  7.5 "ICT"  
				  10.5 "Construction"
				  13.5 "Business Admin & Law"
				  16.5 "Engineering & Manuf."
				  19.5 "Health & Pub Services",
				  angle(45) labsize(small))
				  xtitle("")
				  ytitle("Return")
				  ytitle("Share of students", axis(2))
				  ylabel(`ylab', axis(1))
				  ylabel(`ylab2', axis(2))
				  title("Adults", color(black))
          graphregion(fcolor(white) color(white) lcolor(white))
		  legend(order(1 "After 1 year" 2 "After 5 years" 5 "Students enrolled") rows(1) size(small) region(color(white)));
	#d cr
	graph save adult, replace
restore

grc1leg2 young.gph adult.gph, /*xcommon ycommon*/ graphregion(color(white))
cap erase young.gph 
cap erase adult.gph

graph export "fig_7.pdf", replace 
