set seed 99898

clear all
/* ** *** THIS DO FILE ESTIMATES VA WITH SAMPLE OF 18-20 year olds, including lagged vars ***** */

*************************************************************************
*************************************************************************
***********SHRINKAGE PROCEEDURE FOR RE  REGRESSION *****************
*************************************************************************
*************************************************************************

cap program drop shrinkage_RE_CS
program define shrinkage_RE_CS

*START PROGRAM
keep if sample_coh==1
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

* Summary Stats (Mean and median dependent variable)
cap drop median_wage*
cap drop mean_wage* 
cap drop sd_wage*

su dep_var if sample_coh==1, detail
gen median_dep_var=r(p50)
gen sd_dep_var=r(sd)
gen mean_dep_var=r(mean)

* Predicting residuals from regression
predict residual if e(sample)==1, res
su residual

*Steps to get Var(res)
gen DF=e(df_r) /*(this is N-K-1)*/
egen var_res_pre_2=total(residual^2)
	* Equation (18) from Guarino et al (2014)
gen var_res = var_res_pre_2/DF
drop   var_res_pre_2

*Var(u)
bys inst_id: egen mean_re=mean(residual)
bys inst_id: gen index_inst=1 if _n==1
egen number_of_inst=count(index_inst)
egen var_u_pre_2=total((residual-mean_re)^2)

* Equation (20) from Guarino et al (2014)
gen var_u = var_u_pre_2/(DF-number_of_inst)
drop  var_u_pre_2

* Var(b)
* Equation (21) from Guarino et al (2014)
gen var_b = var_res - var_u
	/*adjustment page 8 Guarino et al 2014:*/
replace var_b=0 if var_b<0 /*JRV 09.06.21: new following shrinkage Young Panel*/

gen stdev_b = sqrt(var_b)
gen as_std_of_dep_var=stdev_b/sd_dep_var

*Eq (15) from Guarino et al (2014) - Shrinkage estimator
bys inst_id: egen obs_inst=count(inst_id) if sample_coh==1
gen inst_VA_adjusted_v1 = mean_re*(var_b/(var_b+(var_u/obs_inst)))


drop index_inst
bys inst_id: gen index_inst=1 if _n==1
sum mean_re if index_inst==1, detail
end 





****************************************************************************************************
use G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\working_dataset_learner_20032007_v3.dta 
****************************************************************************************************

set matsize 2000
************************************************************
*** PROGRAM SHRINKAGE RANDOM EFFECTS CROSS-SECTION ESTIMATES
************************************************************

///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///

* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
/*tab sample 


   Sample of student classification for |
                            regressions |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
ILR: Enrolled in L2/L3 (or higher) cour |  1,267,599       85.54       85.54
  Never observed in education after KS4 |    141,566        9.55       95.10
 ILR: Max level of education:1 or entry |     67,742        4.57       99.67
ILR: student with unknown level of educ |      4,890        0.33      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,481,797      100.00

*/


keep if sample==1
keep if derived_inst_type_num==1
*codebook id 

* STEP 4: Drop those whose main sector based on GLH is in tutorial and enrichment studies or unknown sector 
tab main_sector_noPLW, mi 
drop if main_sector_noPLW==99 | main_sector_noPLW==16 | main_sector_noPLW==17 | main_sector_noPLW==100
*codebook id 


* STEP 5: DROP if last year in education is after 2016
tab last_year_education, mi
drop if last_year_education>=2016
*codebook id 

*Institution ID 
gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)
su obs, detail
drop obs


* Step 7: Drop those who started before 2005 and after 2010
keep if min_acadyear_inst>=2005 & min_acadyear_inst<=2010
*codebook id 


set more off

replace group_HRV_num_w=14 if group_HRV_num_w==99 /*some are classified as not observed, replace as unknown*/


tab main_sector, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"
*label var main_sector16 "Unknown"
*label var main_sector17 "Mixed"


* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector==`i'
}

cap drop glh_main_sector_noPWL_n
gen glh_main_sector_noPWL_n=0
forval i=1/15 {
replace glh_main_sector_noPWL_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}

recode jobseek_benefit_2015 (0=1) (1=0)
label var jobseek_benefit_2015 "Did not receive job seeking benefits in 2015"
********************************
*GLOBALS FOR CONTROLS  
********************************


global controls0_0 "ib0.male"
global controls_coh0 " i.ACC_region_clean i.ks4_acadyr i.last_year_education   i.years_since_start_FE i.age_first_fe i.mode"
global controls_coh0_emp " i.ACC_region_clean i.ks4_acadyr i.last_year_education i.years_since_start_FE i.age_first_fe i.mode"
global controls_coh0_int " i.ACC_region_clean i.ks4_acadyr i.age_first_fe i.mode" 

global controls_coh1  "i.last_year_FEC" 

global mainsector_coh "ib15.main_sector_noPLW " /*ommitted category: business studies*/
global mainsector_int "ib15.main_sector_noPLW " 


global controls_coh2 "ib0.male ib4.ethnicity ib0.english ib0.non_sen ib0.fsmeligible neigh_pov"
global controls_coh2_red "ib0.male ib4.ethnicity ib0.non_sen"

global controls_coh3 	"sd_ks4_score  i.ks4_OFSTED"  
global controls_coh4 	"ib1.ks3_matlev_v2 ib1.ks3_englev_v2"
global controls_coh5 	"ib0.ks2_englev_v2 ib0.ks2_matlev_v2"

global laggedemployment " ib1.employed_t0_t2"
global laggedbenefits "i.jobseek_benefit_t0_t2"

global college_FE_coh "i.ill_upin" 

global neigh "FEcol_barrier_s_07 FEcol_crime_s_07 FEcol_emp_s_07 FEcol_health_s_07 FEcol_idaci_s_07 FEcol_inc_s_07 ILR_barrier_s_07 ILR_crime_s_07 ILR_emp_s_07 ILR_health_s_07 ILR_inc_s_07 ILR_living_s_07"
global neigh_alt  "ILR_barrier_s_07 ILR_crime_s_07 ILR_emp_s_07 ILR_health_s_07 ILR_inc_s_07 ILR_living_s_07"

global glhtypequal "glh_btec_lev1_n glh_key_funct_lev1_n glh_other_voc_lev1_n glh_nvq_lev1_n glh_btec_lev2_n glh_acad_lev2_n glh_key_funct_lev2_n glh_other_voc_lev2_n glh_nvq_lev2_n glh_btec_lev3_n glh_acad_lev3_n glh_keyskills_lev3_n glh_nvq_lev3_n glh_other_voc_lev3_n glh_voc_lev4_n glh_voc_lev5_n glh_tutorials_gce_gcse_n i.ever_hesa"
global glhawarding "glh_AQA_n glh_CG_n glh_EDEXCEL_n glh_NCFE_n glh_OCR_n"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " total_gl_n_hours_1 total_gl_n_hours_2 total_gl_n_hours_3 total_gl_n_hours_4 total_gl_n_hours_5 total_gl_n_hours_6 total_gl_n_hours_7 total_gl_n_hours_8 total_gl_n_hours_9 total_gl_n_hours_10 total_gl_n_hours_11 total_gl_n_hours_12 total_gl_n_hours_13 total_gl_n_hours_14 total_gl_n_hours_15"
global glhbylevel "total_gl_hours_l1_n total_gl_hours_l2_n total_gl_hours_l3_n total_gl_hours_l4plus_n total_gl_hours_unk_n"
global mainactivity "ib13.group_HRV_num_w " /*excluded category: qualifications below level 2*/



ren years_since_finishFEC_base2017 years_since_finishFEC

gen yr_FEC=0 if years_since_finishFEC>=1 & years_since_finishFEC<=5
replace yr_FEC=1 if years_since_finishFEC>=6 & years_since_finishFEC~=.

gen yr_FEC_m=0 if yr_FEC==0 & male==1
replace yr_FEC_m=1 if yr_FEC==1 & male==1

gen yr_FEC_f=0 if yr_FEC==0 & male==0
replace yr_FEC_f=1 if yr_FEC==1 & male==0

gen ever_hesa_m=0 if ever_hesa==0 & male==1
replace ever_hesa_m=1 if ever_hesa==1 & male==1

gen ever_hesa_f=0 if ever_hesa==0 & male==0
replace ever_hesa_f=1 if ever_hesa==1 & male==0


gen ach_lev3_m=0 if achieved_lev3==0 & male==1
replace ach_lev3_m=1 if achieved_lev3==1 & male==1

gen ach_lev3_f=0 if achieved_lev3==0 & male==0
replace ach_lev3_f=1 if achieved_lev3==1 & male==0

*gen tot_glh_enr=total_gl_hours_l1+total_gl_hours_l2+total_gl_hours_l3+total_gl_hours_l4plus
gen share_glh_ach_m=share_glh_ach if  male==1
gen share_glh_ach_f=share_glh_ach if  male==0

gen tot_glh_ach_m=tot_glh_ach if  male==1
gen tot_glh_ach_f=tot_glh_ach if  male==0

***Age (not banded):
cap drop age_first_fe
gen age_first_fe = (min_acadyear_inst-ks4_acadyr)+15
label var age_first_fe "Age first entered FE college"


*************************************************************************************************************
***REGRESSIONS AND VA ESTIMATES:
*************************************************************************************************************


cap drop sample1 
cap drop sample2 
cap drop sample3

gen sample1=(age_first_fe>=16 & age_first_fe<21)
gen sample2=(age_first_fe>17 & age_first_fe<21)
gen sample3=(age_first_fe>=17 & age_first_fe<21)

keep if sample2==1
codebook inst_id
*


cap log close 
log using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\3_Young_CrossSection_VA_Spec1_SEs.log", replace 


**********************************  
*Log daily earnings in 2017 (Male+Female)
**********************************
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_adj_real_earn_day_2017 c.real_earn_day_adj_t0_t2##i.real_earn_day_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_adj_real_earn_day_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_wage"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}


	*Males 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_adj_real_earn_day_2017 c.real_earn_day_adj_t0_t2##i.real_earn_day_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_adj_real_earn_day_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_wage_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	
		*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_adj_real_earn_day_2017 c.real_earn_day_adj_t0_t2##i.real_earn_day_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_adj_real_earn_day_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_wage_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	



local spec0 ""
local spec1 "$controls0_0"
local spec2 "$controls0_0 $controls_coh0 $controls_coh1 "
local spec3 "$controls0_0 $controls_coh0 $controls_coh1 $controls_coh2 $mainsector_coh "
local spec4 "$controls0_0 $controls_coh0 $controls_coh1 $controls_coh2 $mainsector_coh $controls_coh3 $controls_coh4  $controls_coh5"
local spec5 "$controls0_0 $controls_coh0 $controls_coh1 $controls_coh2 $mainsector_coh $controls_coh3 $controls_coh4  $controls_coh5 $neigh"
local spec6 "$controls0_0 $controls_coh0 $controls_coh1 $controls_coh2 $mainsector_coh $controls_coh3 $controls_coh4  $controls_coh5 $neigh c.real_earn_day_adj_t0_t2##i.real_earn_day_adj_t0_t2_meas $laggedemployment "



forvalues x=0/1{
 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.



reg ln_adj_real_earn_day_2017 c.real_earn_day_adj_t0_t2##i.real_earn_day_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
g sample_sbs=(e(sample)==1)

reg ln_adj_real_earn_day_2017 `spec`x'' if sample_sbs==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_adj_real_earn_day_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_wage"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\\2_Young_CrossSection_Spec1_SBS_v2\bootstrap_samples\VA_`dep_var'_`i'_spec`x'.dta", replace 
	restore
}
}
	
	
	










************************************************************************************************************************
*LOG ANNUAL EARNINGS
*****************************************************************************************
*(MALE + FEMALE)
************************************

forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_real_earn_adj_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_real_earn_adj_2017 c.real_earn_adj_t0_t2##i.real_earn_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh  
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_real_earn_adj_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_an_earn"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}


	*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_real_earn_adj_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_real_earn_adj_2017 c.real_earn_adj_t0_t2##i.real_earn_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh if male==1 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_real_earn_adj_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_an_earn_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ln_real_earn_adj_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ln_real_earn_adj_2017 c.real_earn_adj_t0_t2##i.real_earn_adj_t0_t2_meas  $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment  $neigh if male==0 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ln_real_earn_adj_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ln_an_earn_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}		


******************************************************************************************	
***Regressionin LEVELS (no log) but ALL SAMPLE INCLUDING THOSE WITH EARNINGS EQUAL 0
**********************************************************************************************
*Male+Female
*******************************************************************************************
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_real_earn_day_all_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg real_earn_day_all_2017 c.real_earn_day_all_t0_t2##i.real_earn_day_all_t0_t2_meas   $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=real_earn_day_all_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"wage_all"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}


	*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_real_earn_day_all_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg real_earn_day_all_2017 c.real_earn_day_all_t0_t2##i.real_earn_day_all_t0_t2_meas   $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=real_earn_day_all_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"wage_all_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}

	
	*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_real_earn_day_all_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg real_earn_day_all_2017 c.real_earn_day_all_t0_t2##i.real_earn_day_all_t0_t2_meas   $controls_coh0 $controls_coh1 $mainsector_coh $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=real_earn_day_all_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"wage_all_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	
********************************************************************************************************************************************
*** OUTCOME 2: EMPLOYED MORE THAN 90 DAYS IN 2017 
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************


forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_employment_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg employment_2017    $controls_coh0_emp $mainsector_coh $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=employment_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"emp"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}


	*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_employment_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg employment_2017    $controls_coh0_emp $mainsector_coh $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=employment_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"emp_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
	*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_employment_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg employment_2017    $controls_coh0_emp $mainsector_coh $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=employment_2017 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"emp_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	
	
	
********************************************************************************************************************************************
*** OUTCOME 3: EVER HESA
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************	
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ever_hesa.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ever_hesa    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ever_hesa 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ever_hesa"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ever_hesa_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ever_hesa    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ever_hesa 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ever_hesa_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_ever_hesa_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg ever_hesa    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=ever_hesa 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ever_hesa_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	

	
********************************************************************************************************************************************
*** OUTCOME 4: Share GLH Achieved
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************	
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	

********************************************************************************************************************************************
*** OUTCOME 5: Achieved Level 3d
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************	
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	
	
********************************************************************************************************************************************
*** OUTCOME 6: Total GLH Achieved
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach_female.dta"

sort id academicyear
*1. Expand dataset according to frequency we2_CrossSection_Young_VA_Final_Spec1_std_error.doights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach    $controls_coh0_int $mainsector_int $controls_coh1 $controls_coh2 $controls_coh3 $controls_coh4  $controls_coh5 $laggedemployment $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual region_missing mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	

	
	
log close 


* Gather data on young cross section labour market outcomes  outcomes
* total GLH achieved 

* all 
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_tot_glh_ach_young_CrossSection1820_bootstrapsamples.dta", clear 
* males 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_tot_glh_ach_m_young_CrossSection1820_bootstrapsamples.dta"

* females 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_tot_glh_ach_f_young_CrossSection1820_bootstrapsamples.dta"

* share of glh achieved
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_s_glh_ach_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_s_glh_ach_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_s_glh_ach_f_young_CrossSection1820_bootstrapsamples.dta"

* achieved level 3 plus qualification 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ach_lev3_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ach_lev3_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ach_lev3_f_young_CrossSection1820_bootstrapsamples.dta"

* ever hesa 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ever_hesa_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ever_hesa_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ever_hesa_f_young_CrossSection1820_bootstrapsamples.dta"

ren * *_ycs

save "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\data_table4.dta", replace 


* all 
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_emp_young_CrossSection1820_bootstrapsamples.dta", clear 
ren se_sigma_b se_sigma_b_emp
* males 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_emp_m_young_CrossSection1820_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_m

* females 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_emp_f_young_CrossSection1820_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_f

* Log annual earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_an_earn_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_an_earn_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_an_earn_f_young_CrossSection1820_bootstrapsamples.dta"

* log daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_wage_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_wage_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_ln_wage_f_young_CrossSection1820_bootstrapsamples.dta"

* daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_wage_all_young_CrossSection1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_wage_all_m_young_CrossSection1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\VA_wage_all_f_young_CrossSection1820_bootstrapsamples.dta"

ren * *_ycs

save "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\2_Young_CrossSection_Spec1\bootstrap_samples\data_table5_ycs.dta", replace 


