set seed 99999 


*************************************************************************
*************************************************************************
***********SHRINKAGE PROCEEDURE FOR RE PANEL REGRESSION *****************
*************************************************************************
*************************************************************************


cap  program drop shrinkage_RE_PANEL
program define shrinkage_RE_PANEL

* START PROGRAM
keep if sample_coh==1
gen indice_f2=1 if  academicyear==2017
keep if indice_f2==1 & upin_afterFE~=. 
bys upin_afterFE: egen obs2=count(upin_afterFE) 
egen mean_res2017=mean(residual) 
drop if obs2<30 
drop obs2 
 **
su log_earnings, detail
gen median_dep_var=r(p50)
gen sd_dep_var=r(sd)
gen mean_dep_var=r(mean)

*Steps to get Var(res)
egen DF=count(log_earnings)
tab DF
gen K=e(df_m)
tab K
egen var_res_pre_2=total(residual^2) 
	* Equation (18) from Guarino et al (2014)
gen var_res = var_res_pre_2/(DF-K-1) 
drop  var_res_pre_2

*Steps to get Var(u)
bys upin_afterFE: egen mean_re=mean(residual) 
sum mean_re
	*Number of institutions: 
bys upin_afterFE: gen index_inst_l=1 if _n==1
egen number_of_inst=count(index_inst_l)
drop index_inst_l
egen var_u_pre_2=total((residual-mean_re)^2) 
	* Equation (20) from Guarino et al (2014)
gen var_u = var_u_pre_2/(DF-number_of_inst-K-1) 
drop var_u_pre_2

* Steps to get Var(b)
* Equation (21) from Guarino et al (2014)
gen var_b = var_res - var_u
sum var_b
replace var_b=0 if var_b<0 /*adjustment page 8 Guarino et al 2014*/

*Eq (15) from Guarino et al (2014) - Shrinkage estimator
bys upin_afterFE: egen obs_inst=count(upin_afterFE) 
gen adj_va_v1 = mean_re*(var_b/(var_b+(var_u/obs_inst))) 

*shrink towards average of the residual
gen weight=(var_b/(var_b+(var_u/obs_inst)))
gen adj_va = mean_re*weight+(1-weight)*mean_res2017 /*JRV: we shrink to 2017 population mean residuals because we are selecting only 2017 observations*/

bys upin_afterFE: gen index_inst=1 if _n==1
sum mean_re if index_inst==1, detail
sum adj_va if index_inst==1, detail
end 





///**///*********************************///**///
///**///*****SPECIFICATION 1: 18-20 YEAR OLDS, L2 and above in FE Colleges ******///**///
///**///*********************************///**///

clear
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\panel_cohorts_v2_till2017.dta", clear 



///**///*********************************///**///
///**///********Sample restrictions 21/10/2019******///**///
///**///*********************************///**///
*starting point:  1,842,622 
*1) Keeping those on L2+ or never observed 

keep if sample==1 | sample==2

*2) Keeping those in FE colleges only or never observed
keep if derived_inst_type_num==1 | sample==2 

*3) Drop those whose main sector based on GLH is in tutorial and enrichment studies or unknown sector
drop if main_sector_noPLW==99 | main_sector_noPLW==16 | main_sector_noPLW==17 | main_sector_noPLW==100 

*4) DROP if last year in education is after 2016
drop if last_year_education>=2016 & sample!=2
*5) Drop those who started before 2005 and after 2010
keep if (min_acadyear_inst_cs>=2005 & min_acadyear_inst_cs<=2010) | sample==2


/////****** END SAMPLE SELECTION ******/////

cap drop years_since_finish
gen years_since_finish= academicyear- max_acadyear_aims_ex if max_acadyear_aims_ex!=.
replace years_since_finish=0 if years_since_finish<0 & max_acadyear_aims_ex!=.

///////******///////*************///////******///////
///////******///** **Ficticious CONTROL GROUP  ** ** ////
///////*************///////******//////////////******

replace upin_afterFE=99 if sample==2 /*FAKE COLLEGE ID FOR NON ATTENDEES*/ 
***Age (not banded):
cap drop age
gen age = (academicyear-ks4_acadyr)+15
label var age "Age of individual"
gen age_sq=age^2

replace upin_afterFE=. if age<21 & sample==2 
replace inschool=0 if inschool==. & sample==2 
replace inschool=1 if age>=18 & age<=20 & sample==2

replace ill_upin=99 if sample==2 & inschool==1



*Minimum academic year based on ill_upin
* CLAUDIA: SOMETHING SEEMS WRONG WITH THI. The variable is already in the data (see lie 163) 
bys id: egen min_1=min(academicyear) if ill_upin~=.
bys id: egen min_year_upin=max(min_1)
drop min_1

**NEWWWWWWWW: CLAUDIA: I HAVE USED BELOW min_acadyear_inst because this seems to be the correct variable
* ficticious min_year_inst for those never attending: 
ren min_acadyear_inst_panel min_acadyear_inst
replace min_acadyear_inst=2005 if age==18 & sample==2 & academicyear==2005
replace min_acadyear_inst=2006 if age==18 & sample==2 & academicyear==2006
replace min_acadyear_inst=2007 if age==18 & sample==2 & academicyear==2007
replace min_acadyear_inst=2008 if age==18 & sample==2 & academicyear==2008
replace min_acadyear_inst=2009 if age==18 & sample==2 & academicyear==2009
replace min_acadyear_inst=2010 if age==18 & sample==2 & academicyear==2010
replace min_acadyear_inst=2011 if age==18 & sample==2 & academicyear==2011
replace min_acadyear_inst=2012 if age==18 & sample==2 & academicyear==2012

cap drop max_min
bys id : egen max_min=max(min_acadyear_inst) if sample==2 
replace min_acadyear_inst=max_min if sample==2 

replace ACC_region_clean=99 if sample==2


** INDICATOR FOR YEAR BF ENTRY TO FE **

cap drop index  
bys id: gen index=_n
gen d_yr_bef_FE=0
replace d_yr_bef_FE=1 if academicyear==(min_acadyear_inst-1)


bys id: egen max_year=max(academicyear)

bys id: egen ill_upin_ex=max(ill_upin)
gen index1=index
replace index1=. if index>1
cap drop obs
bys ill_upin_ex: egen obs=count(index1)
drop index1 



//***** CREATE INDIVIDUAL TIME VARIABLE ****///

sort id academicyear 
by id: gen time=_n
/////****** END TIME VARIABLE ******/////


				 
gen cum_exp_years_sq=cum_exp_years^2
label var cum_exp_years_sq "Cumulative years of experience squared"


** GENERATE cumulative experience before entry to college 

gen experience_by_FE_entry=cum_exp_years if academicyear==min_acadyear_inst_cs
bys id: egen max_experience_by_FE_entry=max(experience_by_FE_entry)
replace experience_by_FE_entry=max_experience_by_FE_entry if academicyear>=min_acadyear_inst_cs
replace experience_by_FE_entry=cum_exp_years if academicyear<min_acadyear_inst_cs
 

cap drop inst_id 
gen inst_id=upin_afterFE
replace inst_id=1 if upin_afterFE==.

cap drop main_sector_postFE
gen main_sector_postFE=main_sector
replace main_sector_postFE=0 if years_since_finish<=0
label values main_sector_postFE ila_d_secsubjareatier1

cap drop main_sector_noPLW_postFE
gen main_sector_noPLW_postFE=main_sector_noPLW
replace main_sector_noPLW_postFE=0 if years_since_finish<=0
label values main_sector_noPLW_postFE ila_d_secsubjareatier1

foreach var in ever_hesa achieved_lev3 share_glh_ach tot_glh_ach {
cap drop `var'_postFE
gen `var'_postFE=`var'
replace `var'_postFE=0 if years_since_finish<=0
}

foreach var in tot_gl_hours_1_gr_male tot_gl_hours_1_gr_fem tot_gl_hours_2_gr_male tot_gl_hours_2_gr_fem tot_gl_hours_3_gr_male tot_gl_hours_3_gr_fem tot_gl_hours_4_gr_male tot_gl_hours_4_gr_fem tot_gl_hours_5_gr_male tot_gl_hours_5_gr_fem tot_gl_hours_6_gr_male tot_gl_hours_6_gr_fem tot_gl_hours_7_gr_male tot_gl_hours_7_gr_fem tot_gl_hours_8_gr_male tot_gl_hours_8_gr_fem tot_gl_hours_9_gr_male tot_gl_hours_9_gr_fem tot_gl_hours_15_gr_male tot_gl_hours_15_gr_fem tot_gl_hours_20_gr_male tot_gl_hours_20_gr_fem {
replace `var'=`var'/100
replace `var' = 0  if years_since_finish<=0
label var `var' "Total glh (divided by 100) grouped by gender post FE"
}

***Age (not banded):
cap drop age_first_fe
gen age_first_fe = (min_acadyear_inst_cs-ks4_acadyr)+15
label var age_first_fe "Age first entered FE college"



*rename academicyear academicyear_learner
cap drop years_since_startFE
gen years_since_startFE=academicyear-min_acadyear_inst /* this variable can be negative which means years before FE*/
replace years_since_startFE=-6 if years_since_startFE==-7
cap drop years_since_startFE_*
tab  years_since_startFE, gen(years_since_startFE_)
cap drop years_since_startFE_pos
gen years_since_startFE_pos=years_since_startFE+6
cap label drop years_since_startFE_pos
label define years_since_startFE_pos 0 "-6" 1 "-5" 2 "-4" 3 "-3" 4 "-2" 5 "-1" 6 "0" 7 "1" 8 "2" 9 "3" 10 "4" 11 "5" 12 "6" 13 "7" 14 "8" 15 "9" 16 "10" 17 "11"
label values years_since_startFE_pos years_since_startFE_pos
label var years_since_startFE_pos "Time relative to FE start"

tab years_since_startFE_pos  years_since_startFE


egen id_num=group(id)

********************************
*GLOBALS FOR CONTROLS  
********************************

global mainsector1 " ib0.main_sector_noPLW_postFE " /*ommitted business: CH,no omitted is just pre-FE period*/

global college_FE "i.inst_id"
*global controls "cum_exp_years cum_exp_years_sq inschool cum_courses_comp_l0 cum_courses_comp_l1 cum_courses_comp_l2 cum_courses_comp_l3 cum_courses_comp_l4 cum_courses_ach_l0 cum_courses_ach_l1 cum_courses_ach_l2 cum_courses_ach_l3 cum_courses_ach_l4 "
global controls "c.experience_by_FE_entry i.inschool i.ACC_region_clean#i.academicyear age age_sq" /*Jeni: 11.05.2018: excluding bad controls*/

global interactions_yearsexp "i.fsmeligible#c.cum_exp_years i.non_sen#c.cum_exp_years c.neigh_pov#c.cum_exp_years c.sd_ks4_score#c.cum_exp_years  i.ks3_matlev_v2#c.cum_exp_years i.ks3_englev_v2#c.cum_exp_years"


*global controls_emp "inschool cum_courses_comp_l0 cum_courses_comp_l1 cum_courses_comp_l2 cum_courses_comp_l3 cum_courses_comp_l4 cum_courses_ach_l0 cum_courses_ach_l1 cum_courses_ach_l2 cum_courses_ach_l3 cum_courses_ach_l4 "
global controls_emp "i.inschool" /*Jeni: 11.05.2018: excluding bad controls*/
global controls_time "i.academicyear years_since_finish ib4.years_since_startFE_pos"


* controlling for GLH for different types of qualifications (this is not all the possible quals, but only the most important ones)
global glhtypequal "glh_btec_lev1_postFE glh_key_funct_lev1_postFE glh_other_voc_lev1_postFE glh_nvq_lev1_postFE glh_btec_lev2_postFE glh_acad_lev2_postFE glh_key_funct_lev2_postFE glh_other_voc_lev2_postFE glh_nvq_lev2_postFE glh_btec_lev3_postFE glh_acad_lev3_postFE glh_keyskills_lev3_postFE glh_nvq_lev3_postFE glh_other_voc_lev3_postFE glh_voc_lev4_postFE glh_voc_lev5_postFE glh_tutorials_gce_gcse_postFE"
global glhtypequal_yearsexp "c.glh_btec_lev1_postFE#c.cum_exp_years c.glh_key_funct_lev1_postFE#c.cum_exp_years c.glh_other_voc_lev1_postFE#c.cum_exp_years c.glh_nvq_lev1_postFE#c.cum_exp_years c.glh_btec_lev2_postFE#c.cum_exp_years c.glh_acad_lev2_postFE#c.cum_exp_years c.glh_key_funct_lev2_postFE#c.cum_exp_years c.glh_other_voc_lev2_postFE#c.cum_exp_years c.glh_nvq_lev2_postFE#c.cum_exp_years c.glh_btec_lev3_postFE#c.cum_exp_years c.glh_acad_lev3_postFE#c.cum_exp_years c.glh_keyskills_lev3_postFE#c.cum_exp_years c.glh_nvq_lev3_postFE#c.cum_exp_years c.glh_other_voc_lev3_postFE#c.cum_exp_years c.glh_voc_lev4_postFE#c.cum_exp_years c.glh_voc_lev5_postFE#c.cum_exp_years c.glh_tutorials_gce_gcse_postFE#c.cum_exp_years"
global glhawarding "glh_AQA_postFE glh_CG_postFE glh_EDEXCEL_postFE glh_NCFE_postFE glh_OCR_postFE"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " cum_total_glh_n_sector1_postFE cum_total_glh_n_sector2_postFE cum_total_glh_n_sector3_postFE cum_total_glh_n_sector4_postFE cum_total_glh_n_sector5_postFE cum_total_glh_n_sector6_postFE cum_total_glh_n_sector7_postFE cum_total_glh_n_sector8_postFE cum_total_glh_n_sector9_postFE cum_total_glh_n_sector10_postFE cum_total_glh_n_sector11_postFE cum_total_glh_n_sector12_postFE cum_total_glh_n_sector13_postFE cum_total_glh_n_sector14_postFE cum_total_glh_n_sector15_postFE"
global glhbylevel "total_gl_hours_l1_postFE total_gl_hours_l2_postFE total_gl_hours_l3_postFE total_gl_hours_l4plus_postFE total_gl_hours_unk_postFE"


* ENDOGENOUS VARIABLE - grouped GLH - gender specific , sector 20 corresponds to "other"
global glhbysector_grouped_male "tot_gl_hours_1_gr_male  tot_gl_hours_4_gr_male tot_gl_hours_5_gr_male tot_gl_hours_6_gr_male  tot_gl_hours_8_gr_male tot_gl_hours_9_gr_male  tot_gl_hours_15_gr_male tot_gl_hours_20_gr_male"
global glhbysector_grouped_female "tot_gl_hours_1_gr_fem tot_gl_hours_2_gr_fem tot_gl_hours_7_gr_fem tot_gl_hours_8_gr_fem tot_gl_hours_9_gr_fem tot_gl_hours_15_gr_fem tot_gl_hours_20_gr_fem"

recode jobseek_benefit (0=1) (1=0)
label var jobseek_benefit "Did not receive job seeking benefit"


cap drop sample1 
cap drop sample2 
cap drop sample3

gen sample1=1
label var sample1 "Started age 16-20"
gen sample2=(age_first_fe>17 & age_first_fe<21)
label var sample2 "Started age 18-20"
gen sample3=(age_first_fe>=17 & age_first_fe<21)
label var sample3 "Started age 17-20"


tab sample2
keep if sample2==1

cap drop index1
gen index1=index
replace index1=. if index>1
cap drop obs
bys ill_upin_ex: egen obs=count(index1)
drop index1 
*cap codebook ill_upin_ex if obs<100
*drop if obs<100
*(281 observations deleted)
*drop obs 


label var cum_total_glh_n_sector1_postFE "Health, Public Services and Care"
label var cum_total_glh_n_sector2_postFE "Science and Mathematics"
label var cum_total_glh_n_sector3_postFE "Agriculture, Horticulture and Animal Care"
label var cum_total_glh_n_sector4_postFE "Engineering and Manufacturing Technology"
label var cum_total_glh_n_sector5_postFE "Construction, Planning and the Built Environment"
label var cum_total_glh_n_sector6_postFE "Information and Communication Technolog"
label var cum_total_glh_n_sector7_postFE "Retail and Commercial Enterprise"
label var cum_total_glh_n_sector8_postFE "Leisure, Travel and Tourism"
label var cum_total_glh_n_sector9_postFE "Arts, Media and Publishing"
label var cum_total_glh_n_sector10_postFE "History, Philosophy and Theology"
label var cum_total_glh_n_sector11_postFE "Social Sciences" 
label var cum_total_glh_n_sector12_postFE "Languages, Literature and Culture"
label var cum_total_glh_n_sector13_postFE "Education and Training"
label var cum_total_glh_n_sector14_postFE "Preparation for Life and Work"
label var cum_total_glh_n_sector15_postFE "Business, Administration and Law"

label var cum_total_glh_n_sector1_postFE "Health Public Services and Care"
label var cum_total_glh_n_sector2_postFE "Science and Mathematics"
label var cum_total_glh_n_sector3_postFE "Agriculture Horticulture and Animal Care"
label var cum_total_glh_n_sector4_postFE "Engineering and Manufacturing Technology"
label var cum_total_glh_n_sector5_postFE "Construction Planning and the Built Environment"
label var cum_total_glh_n_sector6_postFE "Information and Communication Technolog"
label var cum_total_glh_n_sector7_postFE "Retail and Commercial Enterprise"
label var cum_total_glh_n_sector8_postFE "Leisure Travel and Tourism"
label var cum_total_glh_n_sector9_postFE "Arts Media and Publishing"
label var cum_total_glh_n_sector10_postFE "History Philosophy and Theology"
label var cum_total_glh_n_sector11_postFE "Social Sciences" 
label var cum_total_glh_n_sector12_postFE "Languages Literature and Culture"
label var cum_total_glh_n_sector13_postFE "Education and Training"
label var cum_total_glh_n_sector14_postFE "Preparation for Life and Work"
label var cum_total_glh_n_sector15_postFE "Business Administration and Law"

set matsize 5000

egen id_n=group(id)
xtset id_n

 
cap log close 
log using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\1_YOUNG_PANEL_VA_Spec1_SEs.log", replace 


************************************************************************************************************** 
*** BUILDING WEIGHTS ADJUSTED TO EACH REGRESSION: in do-file 00_bootstrap_samples within the VA results folder
*(TO KEEP NUMBER OF INDIVIDUALS CONSTANT)
*NOTE: RUNNING IT OUTSIDE OF THE LOOP AND SAVING IT IN THE DATA TO NOT RUN IT EACH TIME 
*(WE KEEP BOOTSTRAP SAMPLES CONSTANT ACROSS THE DIFFERENT RUNS TO REPLICATE RESULTS)
**************************************************************************************************************
  
  
    
************************************************************************************

*** REGRESSIONS BELOW WITH FWEIGHTS (WHERE W0=1 FOR ALL - I.E. ORIGINAL REGRESSIONS)


************************************************************************************  
  
  
*** Note I merge in the weights, but inside the preserve, so I dont have to change the names of the weights for each regression and in the shrinkage 
  
  
**********************************  
*Log daily earnings (Male+Female)
**********************************
forvalues i=0/50{
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=ln_adj_real_earn_day /* We need this because of line 156 */
areg ln_adj_real_earn_day $mainsector1 $controls $controls_time if sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)


shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_wage"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}


*Log earnings (Male)
forvalues i=0/50{ 
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=ln_adj_real_earn_day  /* We need this because of line 156 */
areg ln_adj_real_earn_day $mainsector1  $controls $controls_time if male==1 & sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)
shrinkage_RE_PANEL
keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_wage_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}
 

*Log earnings (Female)
forvalues i=0/50{ 
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_adj_real_earn_day_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=ln_adj_real_earn_day  /* We need this because of line 156 */
areg ln_adj_real_earn_day $mainsector1  $controls $controls_time if male==0 & sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)
shrinkage_RE_PANEL
keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_wage_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}




***********************************
**Log annual earnings (Male+Female)
***********************************
forvalues i=0/50{
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_real_earn_adj_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=ln_real_earn_adj /* We need this because of line 156 */
areg ln_real_earn_adj $mainsector1 $controls $controls_time if sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)


shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_an_earn"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}


	*Males: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_real_earn_adj_male.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=ln_real_earn_adj /* We need this because of line 156 */
	areg ln_real_earn_adj $mainsector1 $controls $controls_time if male==1 & sample==1, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_an_earn_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}


	*Females: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_ln_real_earn_adj_female.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=ln_real_earn_adj /* We need this because of line 156 */
	areg ln_real_earn_adj $mainsector1 $controls $controls_time if male==0 & sample==1, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"ln_an_earn_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}



*****************************************
*daily earnings with zeros (Male+Female)
*****************************************
forvalues i=0/50{
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_real_earn_day_all_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=real_earn_day_all /* We need this because of line 156 */
areg real_earn_day_all $mainsector1 $controls $controls_time if sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)


shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"wage_all"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}


	*Males: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_real_earn_day_all_male.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=real_earn_day_all /* We need this because of line 156 */
	areg real_earn_day_all $mainsector1 $controls $controls_time if sample==1 & male==1, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"wage_all_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}

	*Females: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_real_earn_day_all_female.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=real_earn_day_all /* We need this because of line 156 */
	areg real_earn_day_all $mainsector1 $controls $controls_time if sample==1 & male==0, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"wage_all_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_panel_`i'.dta", replace 
restore
}


*************************************************************************
*************************************************************************
***********SHRINKAGE PROCEDURE FOR RE PANEL REGRESSION *****************
************************EMPLOYMENT ***********************************
*************************************************************************


cap  program drop shrinkage_RE_PANEL_E_0
program define shrinkage_RE_PANEL_E_0

* START PROGRAM
keep if sample_coh==1
gen indice_f2=1 if academicyear==2017 
keep if indice_f2==1 & upin_afterFE~=.
bys upin_afterFE: egen obs2=count(upin_afterFE)
egen mean_res2017=mean(residual) 
drop if obs2<30
drop obs2
 **
su log_earnings, detail
gen median_dep_var=r(p50)
gen sd_dep_var=r(sd)
gen mean_dep_var=r(mean)

*Steps to get Var(res)
egen DF=count(log_earnings) 
gen K=e(df_m)
egen var_res_pre_2=total(residual^2)
* Equation (18) from Guarino et al (2014)
gen var_res = var_res_pre_2/(DF-K-1)
drop  var_res_pre_2

*Steps to get Var(u)
bys upin_afterFE: egen mean_re=mean(residual)
	*Number of institutions:
bys upin_afterFE: gen index_inst_l=1 if _n==1
egen number_of_inst=count(index_inst_l) 
drop index_inst_l
egen var_u_pre_2=total((residual-mean_re)^2)
	* Equation (20) from Guarino et al (2014)
gen var_u = var_u_pre_2/(DF-number_of_inst-K-1)
drop var_u_pre_2

* Steps to get Var(b)
* Equation (21) from Guarino et al (2014)
gen var_b = var_res - var_u
sum var_b
replace var_b=0 if var_b<0 /*adjustment page 8 Guarino et al 2014*/

*Eq (15) from Guarino et al (2014) - Shrinkage estimator
bys upin_afterFE: egen obs_inst=count(upin_afterFE) 
gen adj_va_v1 = mean_re*(var_b/(var_b+(var_u/obs_inst)))

*shrink towards average of the residual
gen weight=(var_b/(var_b+(var_u/obs_inst)))
gen adj_va = mean_re*weight+(1-weight)*mean_res2017

bys upin_afterFE: gen index_inst=1 if _n==1
sum mean_re if index_inst==1, detail
sum adj_va if index_inst==1, detail
end

******************************
*** Employed more than 90 days
******************************
forvalues i=0/50{
preserve
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_empl_more90d_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear

*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


gen log_earnings=empl_more90d /* We need this because of line 156 */
areg empl_more90d $mainsector1 $controls $controls_time if sample==1, absorb(id)
predict residual, res
gen sample_coh=(e(sample)==1)


shrinkage_RE_PANEL_E_0

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"emp"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_0_panel_`i'.dta", replace 
restore
}


	***Males: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_empl_more90d_male.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=empl_more90d /* We need this because of line 156 */
	areg empl_more90d $mainsector1 $controls $controls_time if sample==1 & male==1, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL_E_0

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"emp_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_0_panel_`i'.dta", replace 
restore
}

	***Males: 
	forvalues i=0/50{
	preserve
	merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_weights\weights_empl_more90d_female.dta"

	sort id academicyear
	*1. Expand dataset according to frequency weights: 
	expand w`i'
	*2. Generate new unique identifiers: 
	sort id academicyear
	by id academicyear, sort: gen id_prel=_n
	egen id_new=group(id id_prel)
	drop id_prel 
	ren id id_OLD
	ren id_new id
	sort id academicyear

	*Select sample appropriately: 
	keep if _m==3 & w`i'>0 & w`i'!=.


	gen log_earnings=empl_more90d /* We need this because of line 156 */
	areg empl_more90d $mainsector1 $controls $controls_time if sample==1 & male==0, absorb(id)
	predict residual, res
	gen sample_coh=(e(sample)==1)


	shrinkage_RE_PANEL_E_0

	keep inst_id ill_upin adj_va mean_re index_inst residual mean_* median_* sd_* var_b  
	* generate variable for numnber of observations 
	local dep_var `"emp_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1
	rename adj_va adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	sort inst_id

	* VA 
	su adj_va_`dep_var', det 
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_`dep_var'_0_panel_`i'.dta", replace 
restore
}



log close 



*** TABLE 3 *****
* 3 samples: 18-20 cross section, 18- 20 panel, 25-59 panel , 4 outcomes 


* Gather data on young panel 
* Employment 
* all 

use "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_emp_0_panel1820_bootstrapsamples.dta", clear 
ren se_sigma_b se_sigma_b_emp

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_emp_m_0_panel1820_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_m

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_emp_f_0_panel1820_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_f


* Log annual earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_panel1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_m_panel1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_f_panel1820_bootstrapsamples.dta"

* log daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_wage_panel1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_wage_m_panel1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_ln_wage_f_panel1820_bootstrapsamples.dta"

* daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_wage_all_panel1820_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_wage_all_m_panel1820_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\VA_wage_all_f_panel1820_bootstrapsamples.dta"

ren * *_yp 

save "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\1_Young_Panel_Spec1\bootstrap_samples\data_table5_yp.dta", replace 
