set seed 99999 


*************************************************************************
*************************************************************************
***********SHRINKAGE PROCEEDURE FOR RE  REGRESSION *****************
*************************************************************************
*************************************************************************

cap program drop shrinkage_RE_CS
program define shrinkage_RE_CS

*START PROGRAM
keep if sample_coh==1
bys inst_id: egen obs=count(inst_id)
*Dropping institutions with less than 30 individuals
cap codebook inst_id if obs<30
drop if obs<30

* Summary Stats (Mean and median dependent variable)
cap drop median_wage*
cap drop mean_wage* 
cap drop sd_wage*

su dep_var if sample_coh==1, detail
gen median_dep_var=r(p50)
gen sd_dep_var=r(sd)
gen mean_dep_var=r(mean)

* Predicting residuals from regression
predict residual if e(sample)==1, res
su residual

*Steps to get Var(res)
gen DF=e(df_r) /*(this is N-K-1)*/
egen var_res_pre_2=total(residual^2)
	* Equation (18) from Guarino et al (2014)
gen var_res = var_res_pre_2/DF
drop   var_res_pre_2

*Var(u)
bys inst_id: egen mean_re=mean(residual)
bys inst_id: gen index_inst=1 if _n==1
egen number_of_inst=count(index_inst)
egen var_u_pre_2=total((residual-mean_re)^2)

* Equation (20) from Guarino et al (2014)
gen var_u = var_u_pre_2/(DF-number_of_inst)
drop  var_u_pre_2

* Var(b)
* Equation (21) from Guarino et al (2014)
gen var_b = var_res - var_u
	/*adjustment page 8 Guarino et al 2014:*/
replace var_b=0 if var_b<0 /*JRV 09.06.21: new following shrinkage Young Panel*/

gen stdev_b = sqrt(var_b)
gen as_std_of_dep_var=stdev_b/sd_dep_var

*Eq (15) from Guarino et al (2014) - Shrinkage estimator
bys inst_id: egen obs_inst=count(inst_id) if sample_coh==1
gen inst_VA_adjusted_v1 = mean_re*(var_b/(var_b+(var_u/obs_inst)))


drop index_inst
bys inst_id: gen index_inst=1 if _n==1
sum mean_re if index_inst==1, detail
end 


******************************************************************************************************************
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\adultpanel\working_dataset_adults_cross-section.dta", clear 
******************************************************************************************************************
set matsize 2000

///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///

***NOTE: Some sample restrictions already done in do-file "do-files\adult_panel\1_create_learner_aims_mildlyILR.do"

* STEP 0: Keep only those in FE collection
*keep if collection==3 

* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
keep if max_lev>=2 & max_lev!=. 

* STEP 2: Keep only cohorts starting in FEC from 2007 to 2010 (to observe earnings at least 3 years prior to enter, and 5 years after)
keep if min_acadyear>=2007 & min_acadyear<=2010

* STEP 3: Keep only those in General FE and Tertiary (drop Sixth Form Students) -- already done in dofile mentioned above

* STEP 4: Drop those whose main sector is missing 
drop if main_sector_noPLW==. 

* STEP 5: DROP if last year in education is after 2013 // Jeni: not needed here since we do not observe educ after 2012
*drop if last_year_education>=2014

*STEP 6: Drop those with age band first in FE equal to 21-24, or with implausible ages after doing that
*drop if age_first_fe==4
keep if age>=25 & age<=59


* STEP 7: DROP those colleges with less than 200 observations
*Institution ID 
cap ren providerid ill_upin
gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)



*Other changes needed:
replace group_HRV_num_w=14 if group_HRV_num_w==99 

*main sector dummies
tab main_sector_noPLW, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"

* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}

cap drop glh_main_sector_noPWL_n
gen glh_main_sector_noPWL_n=0
forval i=1/15 {
replace glh_main_sector_noPWL_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}


cap drop years_since_start_FE
gen years_since_start_FE=2015-min_acadyear
label var years_since_start_FE "Years since first attended an FE college"


********************************
*GLOBALS FOR CONTROLS  
********************************

global controls_coh0 "i.ACC_region_clean i.min_acadyear i.last_year_FEC i.last_year_ILR total_years_work total_years_work_sq age age_sq i.years_since_start_FE"
global controls_coh0_int "i.ACC_region_clean i.min_acadyear age"
global controls_coh0_emp " i.ACC_region_clean i.min_acadyear i.last_year_FEC i.last_year_ILR age age_sq i.years_since_start_FE"
global mainsector_coh "ib15.main_sector_noPLW c.glh_main_sector_noPWL_n" /*ommitted category: business studies*/
global mainsector_coh2 "ib15.main_sector_noPLW#c.total_years_work"
global mainsector_int "ib15.main_sector_noPLW " 
global controls_coh1 "i.mode i.everapprentice"
global controls_coh2 "ib0.male ib4.ethnicity ib0.learningdiff"
global controls_coh3 ib99.prioratt


*Lagged dependent vars:
***********************

global laggedemployment "employed_t employed_t_1 employed_t_2 employed_t_3"
global laggedbenefits "jobseek_benefit_t jobseek_benefit_t_1 jobseek_benefit_t_2 jobseek_benefit_t_3"

global college_FE_coh "i.ill_upin"  
global neigh "barrier_s_07 crime_s_07 emp_s_07 health_s_07 idaci_s_07 inc_s_07 living_s_07"


global glhtypequal "glh_btec_lev1 glh_key_funct_lev1 glh_other_voc_lev1 glh_nvq_lev1 glh_btec_lev2 glh_acad_lev2 glh_key_funct_lev2 glh_other_voc_lev2 glh_nvq_lev2 glh_btec_lev3 glh_acad_lev3 glh_keyskills_lev3 glh_nvq_lev3 glh_other_voc_lev3 glh_voc_lev4 glh_voc_lev5 glh_tutorials_gce_gcse"
global glhawarding "glh_AQA_n glh_CG_n glh_EDEXCEL_n glh_NCFE_n glh_OCR_n"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " total_gl_n_hours_1 total_gl_n_hours_2 total_gl_n_hours_3 total_gl_n_hours_4 total_gl_n_hours_5 total_gl_n_hours_6 total_gl_n_hours_7 total_gl_n_hours_8 total_gl_n_hours_9 total_gl_n_hours_10 total_gl_n_hours_11 total_gl_n_hours_12 total_gl_n_hours_13 total_gl_n_hours_14 total_gl_n_hours_15"
global glhbylevel "total_gl_hours_l1_n total_gl_hours_l2_n total_gl_hours_l3_n total_gl_hours_l4plus_n total_gl_hours_unk_n"
global mainactivity "ib13.group_HRV_num_w " /*excluded category: qualifications below level 2*/


drop obs 
*************************************************************************************************************
***REGRESSIONS AND VA ESTIMATES:
*************************************************************************************************************

cap log close
log using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\LOG_FILES\3_ADULT_CS_VA_Spec1_std_error.log", replace 





********************************************************************************************************************************************
*** OUTCOME 4: Share GLH Achieved
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************	
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_share_glh_ach_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg share_glh_ach    $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=share_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"s_glh_ach_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	

********************************************************************************************************************************************
*** OUTCOME 5: Achieved Level 3d
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************	
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3    $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh 
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3    $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_achieved_lev3_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg achieved_lev3  $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=achieved_lev3 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"ach_lev3_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	
	
********************************************************************************************************************************************
*** OUTCOME 6: Total GLH Achieved
********************************************************************************************************************************************
***(Male+Female)
**************************************************************************************
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach_2017_all.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
	
	
*Males: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach_2017_male.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==1
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach_m"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}
*Females: 
forvalues i=0/50{
preserve 	
merge m:1 id using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_weights\weights_tot_glh_ach_2017_female.dta"

sort id academicyear
*1. Expand dataset according to frequency weights: 
expand w`i'
*2. Generate new unique identifiers: 
sort id academicyear
by id academicyear, sort: gen id_prel=_n
egen id_new=group(id id_prel)
drop id_prel 
ren id id_OLD
ren id_new id
sort id academicyear


*Select sample appropriately: 
keep if _m==3 & w`i'>0 & w`i'!=.


reg tot_glh_ach $controls_coh0_int $controls_coh1 $mainsector_int $controls_coh2 $controls_coh3 $laggedemployment  $neigh if male==0
cap drop sample_coh 
gen sample_coh=(e(sample)==1)
cap drop sample_ln_adj_real_earn_day_2017
gen sample_ln_adj_real_earn_day_2017=(e(sample)==1)
cap drop obs_ln_adj_real_earn_day_2017
egen obs_ln_adj_real_earn_day_2017=total(sample_ln_adj_real_earn_day_2017)
codebook ill_upin if sample_coh==1


gen dep_var=tot_glh_ach 
shrinkage_RE_CS

	*** SAVE IN VA ONLY IN SEPARATE FILE 
	sum var_b stdev_b as_std_of_dep_var
	keep inst_id ill_upin inst_VA_adjusted_v1 mean_re index_inst residual  mean_* median_* sd_* var_b stdev_b as_std_of_dep_var obs_ln_adj_real_earn_day_2017
	* generate variable for number of observations 
	local dep_var `"tot_glh_ach_f"'
	egen obs_va_`dep_var'=count(residual)
	gen sigma_b_`dep_var'=sqrt(var_b)
	su sigma_b_`dep_var'
	drop residual

	keep if index_inst==1

	rename inst_VA_adjusted_v1 adj_va_`dep_var'
	rename mean_re va_`dep_var'
	
	rename mean_dep_var mean_`dep_var' 
	rename median_dep_var median_`dep_var'
	rename sd_dep_var sd_`dep_var'
	
	sort inst_id
	save  "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_CrossSection_Spec1\bootstrap_samples\VA_`dep_var'_`i'.dta", replace 
	restore
}	
	

	
	
log close 


* all 
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_emp_0_Adult_panel_bootstrapsamples.dta", clear 
ren se_sigma_b se_sigma_b_emp
* males 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_emp_m_0_Adult_panel_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_m

* females 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_emp_f_0_Adult_panel_bootstrapsamples.dta"
ren se_sigma_b se_sigma_b_emp_f

* Log annual earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_Adult_panel_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_m_Adult_panel_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_an_earn_f_Adult_panel_bootstrapsamples.dta"

* log daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_wage_Adult_panel_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_wage_m_Adult_panel_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_ln_wage_f_Adult_panel_bootstrapsamples.dta"

* daily earnings 
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_wage_all_Adult_panel_bootstrapsamples.dta" 

* males
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_wage_all_m_Adult_panel_bootstrapsamples.dta"

* females
append using "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\VA_wage_all_f_Adult_panel_bootstrapsamples.dta"

ren * *_ap

save "G:\Data\CEE\AucejoHupkauRuizValenzuela\regressions\LATEST\ValueAdded\FINAL_PAPER\RESULTS\3_Adult_Panel_Spec1\bootstrap_samples\data_table5_ap.dta", replace 

