****************************************************************************************************
use G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\working_dataset_learner_20032007_v3.dta , clear 
****************************************************************************************************

set matsize 2000
************************************************************
*** PROGRAM SHRINKAGE RANDOM EFFECTS CROSS-SECTION ESTIMATES
************************************************************

///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///

* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
/*tab sample 


   Sample of student classification for |
                            regressions |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
ILR: Enrolled in L2/L3 (or higher) cour |  1,267,599       85.54       85.54
  Never observed in education after KS4 |    141,566        9.55       95.10
 ILR: Max level of education:1 or entry |     67,742        4.57       99.67
ILR: student with unknown level of educ |      4,890        0.33      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,481,797      100.00

*/


keep if sample==1
*codebook id 

* STEP 3: KEep only those in General FE and Tertiary (drop Sixth Form Students) 
/*
. tab derived_inst_type_num

                 derived_inst_type_num |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
      General FE college incl. Tertiary |  1,019,879       80.46       80.46
                     Sixth Form College |    247,720       19.54      100.00
----------------------------------------+-----------------------------------
                                  Total |  1,267,599      100.00


*/
keep if derived_inst_type_num==1
*codebook id 

* STEP 4: Drop those whose main sector based on GLH is in tutorial and enrichment studies or unknown sector 
tab main_sector_noPLW, mi 
drop if main_sector_noPLW==99 | main_sector_noPLW==16 | main_sector_noPLW==17 | main_sector_noPLW==100
*codebook id 


* STEP 5: DROP if last year in education is after 2016
tab last_year_education, mi
drop if last_year_education>=2016
*codebook id 

* STEP 6: DROP those colleges with less than 200 observations
*Institution ID 
gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)


* Step 7: Drop those who started before 2005 and after 2010
keep if min_acadyear_inst>=2005 & min_acadyear_inst<=2010
*codebook id 


set more off

replace group_HRV_num_w=14 if group_HRV_num_w==99 /*some are classified as not observed, replace as unknown*/


*main sector dummies
tab main_sector, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"
*label var main_sector16 "Unknown"
*label var main_sector17 "Mixed"


* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector==`i'
}

cap drop glh_main_sector_noPWL_n
gen glh_main_sector_noPWL_n=0
forval i=1/15 {
replace glh_main_sector_noPWL_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}

recode jobseek_benefit_2015 (0=1) (1=0)
label var jobseek_benefit_2015 "Did not receive job seeking benefits in 2015"




ren years_since_finishFEC_base2017 years_since_finishFEC

gen yr_FEC=0 if years_since_finishFEC>=1 & years_since_finishFEC<=5
replace yr_FEC=1 if years_since_finishFEC>=6 & years_since_finishFEC~=.

gen yr_FEC_m=0 if yr_FEC==0 & male==1
replace yr_FEC_m=1 if yr_FEC==1 & male==1

gen yr_FEC_f=0 if yr_FEC==0 & male==0
replace yr_FEC_f=1 if yr_FEC==1 & male==0

gen ever_hesa_m=0 if ever_hesa==0 & male==1
replace ever_hesa_m=1 if ever_hesa==1 & male==1

gen ever_hesa_f=0 if ever_hesa==0 & male==0
replace ever_hesa_f=1 if ever_hesa==1 & male==0


gen ach_lev3_m=0 if achieved_lev3==0 & male==1
replace ach_lev3_m=1 if achieved_lev3==1 & male==1

gen ach_lev3_f=0 if achieved_lev3==0 & male==0
replace ach_lev3_f=1 if achieved_lev3==1 & male==0

*gen tot_glh_enr=total_gl_hours_l1+total_gl_hours_l2+total_gl_hours_l3+total_gl_hours_l4plus
gen share_glh_ach_m=share_glh_ach if  male==1
gen share_glh_ach_f=share_glh_ach if  male==0

gen tot_glh_ach_m=tot_glh_ach if  male==1
gen tot_glh_ach_f=tot_glh_ach if  male==0

***Age (not banded):
cap drop age_first_fe
gen age_first_fe = (min_acadyear_inst-ks4_acadyr)+15
label var age_first_fe "Age first entered FE college"

gen age_first_fe_gr=1 if age_first_fe>=16 & age_first_fe<=17
replace age_first_fe_gr=2 if age_first_fe>=18 & age_first_fe<=20
replace age_first_fe_gr=3 if age_first_fe_gr==.
label define age_gr 1 "16-17" 2 "18-20"
label values age_first_fe_gr age_gr

gen female=(male==0)
egen total_courses =rowtotal(total_courses_1 total_courses_2 total_courses_3 total_courses_4 total_courses_5 total_courses_6 total_courses_7 total_courses_8 total_courses_9 total_courses_10 total_courses_11 total_courses_12 total_courses_13 total_courses_14 total_courses_15 total_courses_16 total_courses_17)


* Max level courses enrolled while in FE in the period observed: 
g max_lev_fe=0 if courses_l0>0 & courses_l0!=.
replace max_lev_fe=1 if courses_l1>0 & courses_l1!=.
replace max_lev_fe=2 if courses_l2>0 & courses_l2!=.
replace max_lev_fe=3 if courses_l3>0 & courses_l3!=.
replace max_lev_fe=4 if courses_l4>0 & courses_l4!=.

*Other descs per academicyear: gender, age, prior attainment
cap drop maxlev0
g maxlev0=(max_lev_fe==0)
label var maxlev0 "Maximum level enrolled is Entry Level - Level 0"

forvalues i=1(1)4 {
cap drop maxlev`i'
g maxlev`i'=(max_lev_fe==`i')
label var maxlev`i' "Maximum level enrolled is `i'"
}


tab employed_t0_t2, mi
cap drop employed_2yearsbf
gen employed_2yearsbf=(employed_t0_t2!=0 & employed_t0_t2!=.)
label var employed_2yearsbf "Share employed b/f FEC entry" /* This goes back actually up to two years before the FE entry, but includes the entry year itself, so it is like 3 years */

cap drop pos_earnings_t0_t2
gen pos_earnings_t0_t2=(pos_earnings_t==1 | pos_earnings_t_1==1 | pos_earnings_t_2==1)
label var pos_earnings_t0_t2 "Share with pre-FEC earnings measure"

label var total_gl_hours "Total guided learning hours"
cap drop total_courses
egen total_courses=rowtotal(courses_l0 courses_l1 courses_l2 courses_l3 courses_l4)
label var total_courses "Total nb. of courses enrolled"

codebook id 
egen id_num=group(id)

** MAKE DESC STATS TABLE ***


label var female "Share female"
label var days_FE_period_alt "Duration of learning (days)"
label var total_courses "Average nb. of courses enrolled"
label var total_gl_hours "Average guided learning hours enrolled"
label var maxlev2 "Share max. level enrolled: 2"
label var maxlev3 "Share max. level enrolled: 3"
label var maxlev4 "Share max. level enrolled: 4"
label var dist_ks4_FEC_student "Median distance KS4 school to FE college (km)"
label var ever_hesa "Share observed in HE after FE"
label var ever_hesa_ba_pls "Enrolled in BA degree"
label var employed_2yearsbf "Share employed before FEC entry*"
label var pos_earnings_t0_t2 "Share with pre-FEC earnings measure"
label var real_earn_adj_t "Earnings in FEC entry year"
label var real_earn_adj_t_1 "Earnings before FEC entry"
label var real_earn_adj_t_p5 "Earnings 5 years post FEC"
**************************************************************************************************************************************************	
*** BY ENTERING AGE 
cap drop sample3
cap drop sample4 
gen sample3=1
gen sample4=1



*** ALL INDIVIDUALS ****
preserve
ren ks4_acadyr ks4_acadyr_temp
ren age_first_fe_gr ks4_acadyr
drop if ks4_acadyr==3
label var id_num "Students"


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
replace count_provider=. if count_provider>1
label var count_provider "FE Colleges"

bys ill_upin: gen count_provider_all=_n
replace count_provider_all=. if count_provider_all>1


***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for Young Learners" 

**************************************************************************************************************************************************
*** THIS CREATES TABLE 2 
**************************************************************************************************************************************************

global vars_share "female    maxlev2 maxlev3 maxlev4  ever_hesa  "
global vars_cont "total_gl_hours days_FE_period_alt "
global vars_cont_2dec "total_courses   "
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)"  "\\"
	file write fh _n  "" " " "& " " 16-17 " " & " " 18-20" " & " "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in   count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_ks4_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_RR.tex"	

restore 
**************************************************************************************************************************************************	
	
*** ALL MALES ****
preserve
ren ks4_acadyr ks4_acadyr_temp
ren age_first_fe_gr ks4_acadyr
drop if ks4_acadyr==3
keep if male==1
label var id_num "Students"


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
replace count_provider=. if count_provider>1
label var count_provider "FE Colleges"
bys ill_upin: gen count_provider_all=_n
replace count_provider_all=. if count_provider_all>1


***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for Young Learners" 

**************************************************************************************************************************************************
*** THIS CREATES TABLE A1 (ONLINE APPENDIX) 
	
**************************************************************************************************************************************************

global vars_share " maxlev2 maxlev3 maxlev4  ever_hesa  "
global vars_cont "total_gl_hours days_FE_period_alt "
global vars_cont_2dec "total_courses "  
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_male_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)"  "\\"
	file write fh _n  "" " " "& " " 16-17 " " & " " 18-20" " & " "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in   count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_ks4_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_male_RR.tex"

restore 
**************************************************************************************************************************************************	
	
**************************************************************************************************************************************************
*** THIS CREATES TABLE A2 (ONLINE APPENDIX) 
	
**************************************************************************************************************************************************
		
*** ALL FEMALES ****
preserve
ren ks4_acadyr ks4_acadyr_temp
ren age_first_fe_gr ks4_acadyr
drop if ks4_acadyr==3
keep if male==0
label var id_num "Students"


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
replace count_provider=. if count_provider>1
label var count_provider "FE Colleges"
bys ill_upin: gen count_provider_all=_n
replace count_provider_all=. if count_provider_all>1


***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for Young Learners" 



global vars_share " maxlev2 maxlev3 maxlev4  ever_hesa  "
global vars_cont "total_gl_hours days_FE_period_alt "
global vars_cont_2dec "total_courses  " 
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_female_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)"  "\\"
	file write fh _n  "" " " "& " " 16-17 " " & " " 18-20" " & " "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in   count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_ks4_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{4}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==1, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==2, det
		local m3 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_young_female_RR.tex"

restore 
	



	


