
******************************************************************************************************************
use "G:\Data\CEE\AucejoHupkauRuizValenzuela\clean_data\adultpanel\working_dataset_adults_cross-section.dta", clear 
******************************************************************************************************************
set matsize 2000

///**///*********************************///**///
///**///********Sample restrictions******///**///
///**///*********************************///**///



* STEP 1: Keep only those that are enrolled in at least some L2/L3 or higher course 
keep if max_lev>=2 & max_lev!=. 

* STEP 2: Keep only cohorts starting in FEC from 2007 to 2010 (to observe earnings at least 3 years prior to enter, and 5 years after)
keep if min_acadyear>=2007 & min_acadyear<=2010

* STEP 3: Keep only those in General FE and Tertiary (drop Sixth Form Students) 

* STEP 4: Drop those whose main sector is missing 
drop if main_sector_noPLW==. 


*STEP 5: Drop those with age band first in FE equal to 21-24, or with implausible ages after doing that
*drop if age_first_fe==4
keep if age>=25 & age<=59


*Institution ID 
ren providerid ill_upin
gen inst_id=ill_upin
bys inst_id: egen obs=count(inst_id)



*Other changes needed:
replace group_HRV_num_w=14 if group_HRV_num_w==99 /*some are classified as not observed, replace as unknown*/

*main sector dummies
tab main_sector_noPLW, gen(main_sector)

label var main_sector1 "Health, Public Services and Care"
label var main_sector2 "Science and Mathematics"
label var main_sector3 "Agriculture, Horticulture and Animal Care"
label var main_sector4 "Engineering and Manufacturing Technology"
label var main_sector5 "Construction, Planning and the Built Environment"
label var main_sector6 "Information and Communication Technolog"
label var main_sector7 "Retail and Commercial Enterprise"
label var main_sector8 "Leisure, Travel and Tourism"
label var main_sector9 "Arts, Media and Publishing"
label var main_sector10 "History, Philosophy and Theology"
label var main_sector11 "Social Sciences" 
label var main_sector12 "Languages, Literature and Culture"
label var main_sector13 "Education and Training"
label var main_sector14 "Preparation for Life and Work"
label var main_sector15 "Business, Administration and Law"

* generate variable indicating glh in main sector 
cap drop glh_main_sector_n
gen glh_main_sector_n=0
forval i=1/15 {
replace glh_main_sector_n=total_gl_n_hours_`i' if main_sector_noPLW==`i'
}


cap drop years_since_start_FE
gen years_since_start_FE=2015-min_acadyear
label var years_since_start_FE "Years since first attended an FE college"


********************************
*GLOBALS FOR CONTROLS  
********************************

global controls_coh0 "i.ACC_region_clean i.min_acadyear i.last_year_FEC i.last_year_ILR total_years_work total_years_work_sq age age_sq i.years_since_start_FE"
global controls_coh0_emp " i.ACC_region_clean i.min_acadyear i.last_year_FEC i.last_year_ILR age age_sq i.years_since_start_FE"
global mainsector_coh "ib15.main_sector_noPLW c.glh_main_sector_n" /*ommitted category: business*/
global mainsector_coh_bis "ib15.main_sector_noPLW" /*ommitted category: business*/
global mainsector_coh2 "ib15.main_sector_noPLW#c.total_years_work"
global main_sector_bis "ib15.main_sector_noPLW##c.glh_main_sector_n"
global controls_coh1 "i.mode i.everapprentice"
global controls_coh2 "ib0.male ib4.ethnicity ib0.learningdiff"
global controls_coh3 ib99.prioratt


*Lagged dependent vars:
***********************
global laggedemployment "employed_t employed_t_1 employed_t_2 employed_t_3"
global laggedbenefits "jobseek_benefit_t jobseek_benefit_t_1 jobseek_benefit_t_2 jobseek_benefit_t_3"

global college_FE_coh "i.ill_upin" 

global neigh "barrier_s_07 crime_s_07 emp_s_07 health_s_07 idaci_s_07 inc_s_07 living_s_07"


* controlling for GLH for different types of qualifications 
global glhtypequal "glh_btec_lev1 glh_key_funct_lev1 glh_other_voc_lev1 glh_nvq_lev1 glh_btec_lev2 glh_acad_lev2 glh_key_funct_lev2 glh_other_voc_lev2 glh_nvq_lev2 glh_btec_lev3 glh_acad_lev3 glh_keyskills_lev3 glh_nvq_lev3 glh_other_voc_lev3 glh_voc_lev4 glh_voc_lev5 glh_tutorials_gce_gcse"
global glhawarding "glh_AQA_n glh_CG_n glh_EDEXCEL_n glh_NCFE_n glh_OCR_n"
global shareglhawarding "share_glh_AQA share_glh_CG share_glh_EDEXCEL share_glh_NCFE share_glh_OCR"
global glhbysector " total_gl_n_hours_1 total_gl_n_hours_2 total_gl_n_hours_3 total_gl_n_hours_4 total_gl_n_hours_5 total_gl_n_hours_6 total_gl_n_hours_7 total_gl_n_hours_8 total_gl_n_hours_9 total_gl_n_hours_10 total_gl_n_hours_11 total_gl_n_hours_12 total_gl_n_hours_13 total_gl_n_hours_14 total_gl_n_hours_15"
global glhbylevel "total_gl_hours_l1_n total_gl_hours_l2_n total_gl_hours_l3_n total_gl_hours_l4plus_n total_gl_hours_unk_n"
global mainactivity "ib13.group_HRV_num_w " 



*************************************************************************************************************
***REGRESSIONS AND VA ESTIMATES:
*************************************************************************************************************

cap drop obs
bys inst_id: egen obs=count(inst_id)


label var ln_adj_real_earn_day_2015  "Log daily real earnings in 2015 (missing for not employed)"
label var real_earn_day_adj_2015 "Real earnings per day in 2015 (missing for not employed)"
label var real_earn_adj_2015 " Real earnings in 2015 (missing for not employed)"


forvalues i=2(1)4 {
cap drop max_lev`i'
g max_lev`i'=(max_lev==`i')
label var max_lev`i' "Maximum level enrolled is `i'"
}



cap drop sample3
gen sample3=1

cap drop ageband_new
egen ageband_new=cut(age), at(25,30,40,50,60)
label define ageband_new 25 "25-29" 30 "30-39" 40 "40-49" 50 "50-59"
label values ageband_new ageband_new
*************************************************************************************************************************************************	
*** BY ENTERING AGE 
 
egen id_num=group(id)
gen female=(male==0)
label var female "Female"


cap drop employed_2yearsbf
gen employed_2yearsbf=(employed_t==1 | employed_t_1==1 | employed_t_2==1| employed_t_3==1)
label var employed_2yearsbf "Share employed b/f FEC entry" /* This goes back actually up to two years before the FE entry, but includes the entry year itself, so it is like 3 years */

cap drop pos_earnings_t0_t2
gen pos_earnings_t0_t2=(pos_earnings_t==1 | pos_earnings_t_1==1 | pos_earnings_t_2==1)
label var pos_earnings_t0_t2 "Share with pre-FEC earnings measure"


label var female "Share female"
label var days_FE_period "Duration of learnings (days)"
label var total_courses "Average nb. of courses enrolled"
label var total_gl_hours "Average guided learning hours enrolled"
label var max_lev2 "Share max. level enrolled: 2"
label var max_lev3 "Share max. level enrolled: 3"
label var max_lev4 "Share max. level enrolled: 4"
label var dist_home_FEC_student "Median distance to FE college (home)"

label var employed_2yearsbf "Share employed before FEC entry*"
label var pos_earnings_t0_t2 "Share with pre-FEC earnings measure"
label var real_earn_adj_t "Earnings in FEC entry year"
label var real_earn_adj_t_1 "Earnings before FEC entry"
label var real_earn_adj_t_p5 "Earnings 5 years post FEC"

*** ALL***

**************************************************************************************************************************************************
*** THIS CREATES TABLE 3 
**************************************************************************************************************************************************



preserve
ren ageband_new ks4_acadyr
keep if sample3==1
label var id_num "Learners"


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
replace count_provider=. if count_provider>1
bys ill_upin: gen count_provider_all=_n
replace count_provider_all=. if count_provider_all>1

label var count_provider "FE Colleges"

***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for aDULT Learners" 



global vars_share "female    max_lev2 max_lev3 max_lev4  "
global vars_cont "total_gl_hours days_FE_period "
global vars_cont_2dec "total_courses   "
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)" " & " "(4)" " & " "(5)"  "\\"
	file write fh _n  "" " " "& " " 25-29 " " & " " 30-39 " " & " " 40-49 " " & " " 50-59 " " & "  "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in  count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_home_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(p50)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(p50)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_RR.tex"
restore 


**************************************************************************************************************************************************
*** THIS CREATES TABLE A3 
**************************************************************************************************************************************************

**** MALES 

preserve
ren ageband_new ks4_acadyr
keep if sample3==1
label var id_num "Learners"
keep if male==1


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
replace count_provider=. if count_provider>1
label var count_provider "FE Colleges"

bys ill_upin: gen count_provider_all=_n
replace count_provider_all=. if count_provider_all>1


***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for Adult Learners" 

**** NEW VERSION 

global vars_share "max_lev2 max_lev3 max_lev4  "
global vars_cont "total_gl_hours days_FE_period "
global vars_cont_2dec "total_courses   "
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_male_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)" " & " "(4)" " & " "(5)"  "\\"
	file write fh _n  "" " " "& " " 25-29 " " & " " 30-39 " " & " " 40-49 " " & " " 50-59 " " & "  "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in  count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_home_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(p50)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(p50)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_male_RR.tex"
restore 

**************************************************************************************************************************************************
*** THIS CREATES TABLE A4 
**************************************************************************************************************************************************

**** FEMALES 

preserve
ren ageband_new ks4_acadyr
keep if sample3==1
label var id_num "Learners"
keep if male==0


*Number of FE institutions with young learners per cohort: 
cap drop count_provider
bys ill_upin ks4_acadyr: gen count_provider=_n
bys ill_upin: gen count_provider_all=_n

replace count_provider=. if count_provider>1
replace count_provider_all=. if count_provider_all>1

label var count_provider "FE Colleges"

***Table of descriptive stats - general
***************************************
local sample3 "Summary Statistics for Young Learners" 

**** NEW VERSION 

global vars_share "max_lev2 max_lev3 max_lev4  "
global vars_cont "total_gl_hours days_FE_period "
global vars_cont_2dec "total_courses   "
global vars_emp "employed_2yearsbf"
global vars_earn "real_earn_adj_t real_earn_adj_t_1 real_earn_adj_t_p5"

cap file close fh
file open fh using "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_female_RR.tex", write replace
	file write fh _n  "\begin{tabular}{@{}lccccc@{}}"
	file write fh _n "\toprule" 
	file write fh _n  "" " " "& " "(1)" " & " "(2)" " & " "(3)" " & " "(4)" " & " "(5)"  "\\"
	file write fh _n  "" " " "& " " 25-29 " " & " " 30-39 " " & " " 40-49 " " & " " 50-59 " " & "  "Total" "\\"
		file write fh _n"\midrule" 
		foreach var in id_num   {
		su `var' if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in  count_provider {
		su count_provider_all if ks4_acadyr!=., det
		local m1 = r(N)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(N)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(N)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(N)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(N)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Learner Characteristics}}" "\\"	
		foreach var in $vars_share  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_cont  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		foreach var in $vars_cont_2dec  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in dist_home_FEC_student  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(p50)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(p50)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(p50)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(p50)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(p50)
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		file write fh _n "\multicolumn{6}{l}{\textbf{Labour market characteristics}}" "\\"	
		foreach var in $vars_emp  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)*100
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)*100
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)*100
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)*100
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)*100
		file write fh _n `"`: var label `var''"'  " & " %9.2fc (`m2') " & " %9.2fc (`m3') " & " %9.2fc (`m4')  " & " %9.2fc (`m5')  " & " %9.2fc (`m1') " \\"
		}
		foreach var in $vars_earn  {
		su `var' if ks4_acadyr!=., det
		local m1 = r(mean)
		su `var'  if ks4_acadyr==25, det
		local m2 = r(mean)
		su `var'  if ks4_acadyr==30, det
		local m3 = r(mean)
		su `var'  if ks4_acadyr==40, det
		local m4 = r(mean)
		su `var'  if ks4_acadyr==50, det
		local m5 = r(mean)
		file write fh _n `"`: var label `var''"'  " & " %9.0fc (`m2') " & " %9.0fc (`m3') " & " %9.0fc (`m4')  " & " %9.0fc (`m5')  " & " %9.0fc (`m1') " \\"
		}
		file write fh _n "\bottomrule" 
		file write fh _n "\end{tabular}"

file close fh
type "J:\Projects\Value Added Further Education\FINAL_TABLES\resubmission\desc_stats_adult_female_RR.tex"
restore 